"""Design tokens for md.comp.date-picker."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

docked_container_color = _define_token("md.sys.color.surface-container-high")
docked_container_elevation = _define_token("md.sys.elevation.level3")
docked_container_height = _define_token(456)
docked_container_shape = _define_token("md.sys.shape.corner.large")
docked_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
docked_container_width = _define_token(360)
docked_date_container_height = _define_token(48)
docked_date_container_shape = _define_token("md.sys.shape.corner.full")
docked_date_container_width = _define_token(48)
docked_date_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
docked_date_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
docked_date_label_text_font = _define_token("md.sys.typescale.body-large.font")
docked_date_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
docked_date_label_text_size = _define_token("md.sys.typescale.body-large.size")
docked_date_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
docked_date_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
docked_date_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
docked_date_selected_container_color = _define_token("md.sys.color.primary")
docked_date_selected_focus_state_layer_color = _define_token("md.sys.color.on-primary")
docked_date_selected_hover_state_layer_color = _define_token("md.sys.color.on-primary")
docked_date_selected_label_text_color = _define_token("md.sys.color.on-primary")
docked_date_selected_pressed_state_layer_color = _define_token("md.sys.color.on-primary")
docked_date_state_layer_height = _define_token(40)
docked_date_state_layer_shape = _define_token("md.sys.shape.corner.full")
docked_date_state_layer_width = _define_token(40)
docked_date_today_container_outline_color = _define_token("md.sys.color.primary")
docked_date_today_container_outline_width = _define_token(1)
docked_date_today_focus_state_layer_color = _define_token("md.sys.color.primary")
docked_date_today_hover_state_layer_color = _define_token("md.sys.color.primary")
docked_date_today_label_text_color = _define_token("md.sys.color.primary")
docked_date_today_pressed_state_layer_color = _define_token("md.sys.color.primary")
docked_date_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_date_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_date_unselected_label_text_color = _define_token("md.sys.color.on-surface")
docked_date_unselected_outside_month_label_text_color = _define_token("md.sys.color.outline-variant")
docked_date_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_header_height = _define_token(64)
docked_menu_button_container_height = _define_token(40)
docked_menu_button_container_shape = _define_token("md.sys.shape.corner.full")
docked_menu_button_disabled_icon_color = _define_token("md.sys.color.on-surface")
docked_menu_button_disabled_icon_opacity = _define_token(0.38)
docked_menu_button_disabled_label_text_color = _define_token("md.sys.color.on-surface")
docked_menu_button_disabled_label_text_opacity = _define_token(0.38)
docked_menu_button_focus_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_focus_label_text_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
docked_menu_button_hover_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
docked_menu_button_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_icon_size = _define_token(18)
docked_menu_button_label_text_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_label_text_font = _define_token("md.sys.typescale.label-large.font")
docked_menu_button_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
docked_menu_button_label_text_size = _define_token("md.sys.typescale.label-large.size")
docked_menu_button_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
docked_menu_button_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
docked_menu_button_pressed_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_pressed_label_text_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_button_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
docked_menu_list_item_container_height = _define_token(48)
docked_menu_list_item_focus_label_text_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_focus_state_layer_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
docked_menu_list_item_hover_label_text_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_hover_state_layer_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
docked_menu_list_item_label_text_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_label_text_font = _define_token("md.sys.typescale.body-large.font")
docked_menu_list_item_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
docked_menu_list_item_label_text_size = _define_token("md.sys.typescale.body-large.size")
docked_menu_list_item_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
docked_menu_list_item_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
docked_menu_list_item_pressed_label_text_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
docked_menu_list_item_selected_container_color = _define_token("md.sys.color.surface-variant")
docked_menu_list_item_selected_focus_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_list_item_selected_hover_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_menu_list_item_selected_leading_icon_color = _define_token("md.sys.color.on-surface")
docked_menu_list_item_selected_leading_icon_size = _define_token(24)
docked_menu_list_item_selected_pressed_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
docked_weekdays_label_text_color = _define_token("md.sys.color.on-surface")
docked_weekdays_label_text_font = _define_token("md.sys.typescale.body-large.font")
docked_weekdays_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
docked_weekdays_label_text_size = _define_token("md.sys.typescale.body-large.size")
docked_weekdays_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
docked_weekdays_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
modal_container_color = _define_token("md.sys.color.surface-container-high")
modal_container_elevation = _define_token("md.sys.elevation.level3")
modal_container_height = _define_token(568)
modal_container_shape = _define_token("md.sys.shape.corner.extra-large")
modal_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
modal_container_width = _define_token(360)
modal_date_container_height = _define_token(40)
modal_date_container_shape = _define_token("md.sys.shape.corner.full")
modal_date_container_width = _define_token(40)
modal_date_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
modal_date_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
modal_date_label_text_font = _define_token("md.sys.typescale.body-large.font")
modal_date_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
modal_date_label_text_size = _define_token("md.sys.typescale.body-large.size")
modal_date_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
modal_date_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
modal_date_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
modal_date_selected_container_color = _define_token("md.sys.color.primary")
modal_date_selected_focus_state_layer_color = _define_token("md.sys.color.on-primary")
modal_date_selected_hover_state_layer_color = _define_token("md.sys.color.on-primary")
modal_date_selected_label_text_color = _define_token("md.sys.color.on-primary")
modal_date_selected_pressed_state_layer_color = _define_token("md.sys.color.on-primary")
modal_date_state_layer_height = _define_token(40)
modal_date_state_layer_shape = _define_token("md.sys.shape.corner.full")
modal_date_state_layer_width = _define_token(40)
modal_date_today_container_outline_color = _define_token("md.sys.color.primary")
modal_date_today_container_outline_width = _define_token(1)
modal_date_today_focus_state_layer_color = _define_token("md.sys.color.primary")
modal_date_today_hover_state_layer_color = _define_token("md.sys.color.primary")
modal_date_today_label_text_color = _define_token("md.sys.color.primary")
modal_date_today_pressed_state_layer_color = _define_token("md.sys.color.primary")
modal_date_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
modal_date_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
modal_date_unselected_label_text_color = _define_token("md.sys.color.on-surface")
modal_date_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
modal_header_container_height = _define_token(120)
modal_header_container_width = _define_token(360)
modal_header_headline_color = _define_token("md.sys.color.on-surface-variant")
modal_header_headline_font = _define_token("md.sys.typescale.headline-large.font")
modal_header_headline_line_height = _define_token("md.sys.typescale.headline-large.line-height")
modal_header_headline_size = _define_token("md.sys.typescale.headline-large.size")
modal_header_headline_tracking = _define_token("md.sys.typescale.headline-large.tracking")
modal_header_headline_weight = _define_token("md.sys.typescale.headline-large.weight")
modal_header_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
modal_header_supporting_text_font = _define_token("md.sys.typescale.label-large.font")
modal_header_supporting_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
modal_header_supporting_text_size = _define_token("md.sys.typescale.label-large.size")
modal_header_supporting_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
modal_header_supporting_text_weight = _define_token("md.sys.typescale.label-large.weight")
modal_range_selection_active_indicator_container_color = _define_token("md.sys.color.secondary-container")
modal_range_selection_active_indicator_container_height = _define_token(40)
modal_range_selection_active_indicator_container_shape = _define_token("md.sys.shape.corner.full")
modal_range_selection_container_elevation = _define_token("md.sys.elevation.level0")
modal_range_selection_container_shape = _define_token("md.sys.shape.corner.none")
modal_range_selection_date_in_range_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
modal_range_selection_date_in_range_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
modal_range_selection_date_in_range_focus_state_layer_opcaity = _define_token("md.sys.state.focus.state-layer-opacity")
modal_range_selection_date_in_range_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
modal_range_selection_date_in_range_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
modal_range_selection_date_in_range_hover_state_layer_opcaity = _define_token("md.sys.state.hover.state-layer-opacity")
modal_range_selection_date_in_range_label_text_color = _define_token("md.sys.color.on-secondary-container")
modal_range_selection_date_in_range_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
modal_range_selection_date_in_range_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
modal_range_selection_date_in_range_pressed_state_layer_opcaity = _define_token("md.sys.state.pressed.state-layer-opacity")
modal_range_selection_header_container_height = _define_token(128)
modal_range_selection_header_headline_font = _define_token("md.sys.typescale.title-large.font")
modal_range_selection_header_headline_line_height = _define_token("md.sys.typescale.title-large.line-height")
modal_range_selection_header_headline_size = _define_token("md.sys.typescale.title-large.size")
modal_range_selection_header_headline_tracking = _define_token("md.sys.typescale.title-large.tracking")
modal_range_selection_header_headline_weight = _define_token("md.sys.typescale.title-large.weight")
modal_range_selection_month_subhead_color = _define_token("md.sys.color.on-surface-variant")
modal_range_selection_month_subhead_font = _define_token("md.sys.typescale.title-small.font")
modal_range_selection_month_subhead_line_height = _define_token("md.sys.typescale.title-small.line-height")
modal_range_selection_month_subhead_size = _define_token("md.sys.typescale.title-small.size")
modal_range_selection_month_subhead_tracking = _define_token("md.sys.typescale.title-small.tracking")
modal_range_selection_month_subhead_weight = _define_token("md.sys.typescale.title-small.weight")
modal_weekdays_label_text_color = _define_token("md.sys.color.on-surface")
modal_weekdays_label_text_font = _define_token("md.sys.typescale.body-large.font")
modal_weekdays_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
modal_weekdays_label_text_size = _define_token("md.sys.typescale.body-large.size")
modal_weekdays_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
modal_weekdays_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
modal_year_selection_year_container_height = _define_token(36)
modal_year_selection_year_container_width = _define_token(72)
modal_year_selection_year_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
modal_year_selection_year_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
modal_year_selection_year_label_text_font = _define_token("md.sys.typescale.body-large.font")
modal_year_selection_year_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
modal_year_selection_year_label_text_size = _define_token("md.sys.typescale.body-large.size")
modal_year_selection_year_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
modal_year_selection_year_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
modal_year_selection_year_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
modal_year_selection_year_selected_container_color = _define_token("md.sys.color.primary")
modal_year_selection_year_selected_focus_state_layer_color = _define_token("md.sys.color.on-primary")
modal_year_selection_year_selected_hover_state_layer_color = _define_token("md.sys.color.on-primary")
modal_year_selection_year_selected_label_text_color = _define_token("md.sys.color.on-primary")
modal_year_selection_year_selected_pressed_state_layer_color = _define_token("md.sys.color.on-primary")
modal_year_selection_year_state_layer_height = _define_token(36)
modal_year_selection_year_state_layer_shape = _define_token("md.sys.shape.corner.full")
modal_year_selection_year_state_layer_width = _define_token(72)
modal_year_selection_year_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
modal_year_selection_year_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
modal_year_selection_year_unselected_label_text_color = _define_token("md.sys.color.on-surface-variant")
modal_year_selection_year_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
