"""Design tokens for md.comp.sheet."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

bottom_docked_container_color = _define_token("md.sys.color.surface-container-low")
bottom_docked_container_shape = _define_token("md.sys.shape.corner.extra-large.top")
bottom_docked_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
bottom_docked_drag_handle_color = _define_token("md.sys.color.on-surface-variant")
bottom_docked_drag_handle_height = _define_token(4)
bottom_docked_drag_handle_opacity = _define_token(0.4)
bottom_docked_drag_handle_width = _define_token(32)
bottom_docked_minimized_container_shape = _define_token("md.sys.shape.corner.none")
bottom_docked_modal_container_elevation = _define_token("md.sys.elevation.level1")
bottom_docked_standard_container_elevation = _define_token("md.sys.elevation.level1")
bottom_focus_indicator_color = _define_token("md.sys.color.secondary")
bottom_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
bottom_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
side_detached_container_shape = _define_token("md.sys.shape.corner.large")
side_docked_action_focus_label_text_color = _define_token("md.sys.color.primary")
side_docked_action_focus_state_layer_color = _define_token("md.sys.color.primary")
side_docked_action_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
side_docked_action_hover_label_text_color = _define_token("md.sys.color.primary")
side_docked_action_hover_state_layer_color = _define_token("md.sys.color.primary")
side_docked_action_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
side_docked_action_pressed_label_text_color = _define_token("md.sys.color.primary")
side_docked_action_pressed_state_layer_color = _define_token("md.sys.color.primary")
side_docked_action_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
side_docked_container_color = _define_token("md.sys.color.surface")
side_docked_container_height = _define_token(1.0)
side_docked_container_shape = _define_token("md.sys.shape.corner.none")
side_docked_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
side_docked_container_width = _define_token(256)
side_docked_divider_color = _define_token("md.sys.color.outline")
side_docked_focus_indicator_color = _define_token("md.sys.color.secondary")
side_docked_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
side_docked_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
side_docked_headline_color = _define_token("md.sys.color.on-surface-variant")
side_docked_headline_font = _define_token("md.sys.typescale.title-large.font")
side_docked_headline_line_height = _define_token("md.sys.typescale.title-large.line-height")
side_docked_headline_size = _define_token("md.sys.typescale.title-large.size")
side_docked_headline_tracking = _define_token("md.sys.typescale.title-large.tracking")
side_docked_headline_weight = _define_token("md.sys.typescale.title-large.weight")
side_docked_modal_container_color = _define_token("md.sys.color.surface-container-low")
side_docked_modal_container_elevation = _define_token("md.sys.elevation.level1")
side_docked_modal_container_shape = _define_token("md.sys.shape.corner.large.start")
side_docked_standard_container_color = _define_token("md.sys.color.surface")
side_docked_standard_container_elevation = _define_token("md.sys.elevation.level0")
