"""Design tokens for md.sys.typescale."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

body_large_font = _define_token("md.ref.typeface.plain")
body_large_line_height = _define_token(24)
body_large_size = _define_token(16)
body_large_tracking = _define_token(0.5)
body_large_weight = _define_token("md.ref.typeface.weight-regular")
body_medium_font = _define_token("md.ref.typeface.plain")
body_medium_line_height = _define_token(20)
body_medium_size = _define_token(14)
body_medium_tracking = _define_token(0.25)
body_medium_weight = _define_token("md.ref.typeface.weight-regular")
body_small_font = _define_token("md.ref.typeface.plain")
body_small_line_height = _define_token(16)
body_small_size = _define_token(12)
body_small_tracking = _define_token(0.4)
body_small_weight = _define_token("md.ref.typeface.weight-regular")
display_large_font = _define_token("md.ref.typeface.brand")
display_large_line_height = _define_token(64)
display_large_size = _define_token(57)
display_large_tracking = _define_token(-0.25)
display_large_weight = _define_token("md.ref.typeface.weight-regular")
display_medium_font = _define_token("md.ref.typeface.brand")
display_medium_line_height = _define_token(52)
display_medium_size = _define_token(45)
display_medium_tracking = _define_token(0)
display_medium_weight = _define_token("md.ref.typeface.weight-regular")
headline_large_font = _define_token("md.ref.typeface.brand")
headline_large_line_height = _define_token(40)
headline_large_size = _define_token(32)
headline_large_tracking = _define_token(0)
headline_large_weight = _define_token("md.ref.typeface.weight-regular")
headline_medium_font = _define_token("md.ref.typeface.brand")
headline_medium_line_height = _define_token(36)
headline_medium_size = _define_token(28)
headline_medium_tracking = _define_token(0)
headline_medium_weight = _define_token("md.ref.typeface.weight-regular")
headline_small_font = _define_token("md.ref.typeface.brand")
headline_small_line_height = _define_token(32)
headline_small_size = _define_token(24)
headline_small_tracking = _define_token(0)
headline_small_weight = _define_token("md.ref.typeface.weight-regular")
label_large_font = _define_token("md.ref.typeface.plain")
label_large_line_height = _define_token(20)
label_large_size = _define_token(14)
label_large_tracking = _define_token(0.1)
label_large_weight = _define_token("md.ref.typeface.weight-medium")
label_large_weight_prominent = _define_token("md.ref.typeface.weight-bold")
label_medium_font = _define_token("md.ref.typeface.plain")
label_medium_line_height = _define_token(16)
label_medium_size = _define_token(12)
label_medium_tracking = _define_token(0.5)
label_medium_weight = _define_token("md.ref.typeface.weight-medium")
label_medium_weight_prominent = _define_token("md.ref.typeface.weight-bold")
label_small_font = _define_token("md.ref.typeface.plain")
label_small_line_height = _define_token(16)
label_small_size = _define_token(11)
label_small_tracking = _define_token(0.5)
label_small_weight = _define_token("md.ref.typeface.weight-medium")
title_large_font = _define_token("md.ref.typeface.brand")
title_large_line_height = _define_token(28)
title_large_size = _define_token(22)
title_large_tracking = _define_token(0)
title_large_weight = _define_token("md.ref.typeface.weight-regular")
title_medium_font = _define_token("md.ref.typeface.plain")
title_medium_line_height = _define_token(24)
title_medium_size = _define_token(16)
title_medium_tracking = _define_token(0.15)
title_medium_weight = _define_token("md.ref.typeface.weight-medium")
title_small_font = _define_token("md.ref.typeface.plain")
title_small_line_height = _define_token(20)
title_small_size = _define_token(14)
title_small_tracking = _define_token(0.1)
title_small_weight = _define_token("md.ref.typeface.weight-medium")
