"""Common imports for Material UI components."""

from material_ui.shape import Shape
from material_ui.switch import Switch
from material_ui import buttons
from material_ui.typography import Typography
from material_ui._component import Component, use_state, effect

__all__ = [
    "Component",
    "Shape",
    "Switch",
    "Typography",
    "use_state",
    "effect",
    "buttons",
]
