"""Design tokens for md.sys.color."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

error = _define_token("md.ref.palette.error40")
error_container = _define_token("md.ref.palette.error90")
inverse_on_surface = _define_token("md.ref.palette.neutral95")
inverse_primary = _define_token("md.ref.palette.primary80")
inverse_surface = _define_token("md.ref.palette.neutral20")
on_error = _define_token("md.ref.palette.error100")
on_error_container = _define_token("md.ref.palette.error30")
on_primary = _define_token("md.ref.palette.primary100")
on_primary_container = _define_token("md.ref.palette.primary30")
on_secondary = _define_token("md.ref.palette.secondary100")
on_secondary_container = _define_token("md.ref.palette.secondary30")
on_surface = _define_token("md.ref.palette.neutral10")
on_surface_variant = _define_token("md.ref.palette.neutral-variant30")
on_tertiary = _define_token("md.ref.palette.tertiary30")
on_tertiary_container = _define_token("md.ref.palette.tertiary30")
outline = _define_token("md.ref.palette.neutral-variant50")
outline_variant = _define_token("md.ref.palette.neutral-variant80")
primary = _define_token("md.ref.palette.primary40")
primary_container = _define_token("md.ref.palette.primary90")
secondary = _define_token("md.ref.palette.secondary40")
secondary_container = _define_token("md.ref.palette.secondary90")
shadow = _define_token("md.ref.palette.neutral0")
surface = _define_token("md.ref.palette.neutral98")
surface_bright = _define_token("md.ref.palette.neutral98")
surface_container = _define_token("md.ref.palette.neutral94")
surface_container_high = _define_token("md.ref.palette.neutral92")
surface_container_highest = _define_token("md.ref.palette.neutral90")
surface_container_low = _define_token("md.ref.palette.neutral96")
surface_container_lowest = _define_token("md.ref.palette.neutral100")
surface_dim = _define_token("md.ref.palette.neutral87")
surface_tint = _define_token("md.sys.color.primary")
surface_variant = _define_token("md.ref.palette.neutral-variant90")
tertiary = _define_token("md.ref.palette.tertiary40")
tertiary_container = _define_token("md.ref.palette.tertiary90")
background = _define_token("md.ref.palette.white")
