"""Design tokens for md.comp.snackbar."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

action_focus_label_text_color = _define_token("md.sys.color.inverse-primary")
action_focus_state_layer_color = _define_token("md.sys.color.inverse-primary")
action_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
action_hover_label_text_color = _define_token("md.sys.color.inverse-primary")
action_hover_state_layer_color = _define_token("md.sys.color.inverse-primary")
action_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
action_label_text_color = _define_token("md.sys.color.inverse-primary")
action_label_text_font = _define_token("md.sys.typescale.label-large.font")
action_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
action_label_text_size = _define_token("md.sys.typescale.label-large.size")
action_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
action_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
action_pressed_label_text_color = _define_token("md.sys.color.inverse-primary")
action_pressed_state_layer_color = _define_token("md.sys.color.inverse-primary")
action_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
container_color = _define_token("md.sys.color.inverse-surface")
container_elevation = _define_token("md.sys.elevation.level3")
container_shadow_color = _define_token("md.sys.color.shadow")
container_shape = _define_token("md.sys.shape.corner.extra-small")
icon_color = _define_token("md.sys.color.inverse-on-surface")
icon_focus_icon_color = _define_token("md.sys.color.inverse-on-surface")
icon_focus_state_layer_color = _define_token("md.sys.color.inverse-on-surface")
icon_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
icon_hover_icon_color = _define_token("md.sys.color.inverse-on-surface")
icon_hover_state_layer_color = _define_token("md.sys.color.inverse-on-surface")
icon_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
icon_pressed_icon_color = _define_token("md.sys.color.inverse-on-surface")
icon_pressed_state_layer_color = _define_token("md.sys.color.inverse-on-surface")
icon_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
icon_size = _define_token(24)
supporting_text_color = _define_token("md.sys.color.inverse-on-surface")
supporting_text_font = _define_token("md.sys.typescale.body-medium.font")
supporting_text_line_height = _define_token("md.sys.typescale.body-medium.line-height")
supporting_text_size = _define_token("md.sys.typescale.body-medium.size")
supporting_text_tracking = _define_token("md.sys.typescale.body-medium.tracking")
supporting_text_weight = _define_token("md.sys.typescale.body-medium.weight")
with_single_line_container_height = _define_token(48)
with_two_lines_container_height = _define_token(68)
