"""Design tokens for md.ref.palette."""

from qtpy.QtGui import QColor

from material_ui.tokens._utils import define_token as _define_token

black = _define_token(QColor("#000000"))
error0 = _define_token(QColor("#000000"))
error10 = _define_token(QColor("#410e0b"))
error100 = _define_token(QColor("#ffffff"))
error20 = _define_token(QColor("#601410"))
error30 = _define_token(QColor("#8c1d18"))
error40 = _define_token(QColor("#b3261e"))
error50 = _define_token(QColor("#dc362e"))
error60 = _define_token(QColor("#e46962"))
error70 = _define_token(QColor("#ec928e"))
error80 = _define_token(QColor("#f2b8b5"))
error90 = _define_token(QColor("#f9dedc"))
error95 = _define_token(QColor("#fceeee"))
error99 = _define_token(QColor("#fffbf9"))
neutral_variant0 = _define_token(QColor("#000000"))
neutral_variant10 = _define_token(QColor("#1d1a22"))
neutral_variant100 = _define_token(QColor("#ffffff"))
neutral_variant20 = _define_token(QColor("#322f37"))
neutral_variant30 = _define_token(QColor("#49454f"))
neutral_variant40 = _define_token(QColor("#605d66"))
neutral_variant50 = _define_token(QColor("#79747e"))
neutral_variant60 = _define_token(QColor("#938f99"))
neutral_variant70 = _define_token(QColor("#aea9b4"))
neutral_variant80 = _define_token(QColor("#cac4d0"))
neutral_variant90 = _define_token(QColor("#e7e0ec"))
neutral_variant95 = _define_token(QColor("#f5eefa"))
neutral_variant99 = _define_token(QColor("#fffbfe"))
neutral0 = _define_token(QColor("#000000"))
neutral10 = _define_token(QColor("#1d1b20"))
neutral100 = _define_token(QColor("#ffffff"))
neutral12 = _define_token(QColor("#211f26"))
neutral17 = _define_token(QColor("#2b2930"))
neutral20 = _define_token(QColor("#322f35"))
neutral22 = _define_token(QColor("#36343b"))
neutral24 = _define_token(QColor("#3b383e"))
neutral30 = _define_token(QColor("#48464c"))
neutral4 = _define_token(QColor("#0f0d13"))
neutral40 = _define_token(QColor("#605d64"))
neutral50 = _define_token(QColor("#79767d"))
neutral6 = _define_token(QColor("#141218"))
neutral60 = _define_token(QColor("#938f96"))
neutral70 = _define_token(QColor("#aea9b1"))
neutral80 = _define_token(QColor("#cac5cd"))
neutral87 = _define_token(QColor("#ded8e1"))
neutral90 = _define_token(QColor("#e6e0e9"))
neutral92 = _define_token(QColor("#ece6f0"))
neutral94 = _define_token(QColor("#f3edf7"))
neutral95 = _define_token(QColor("#f5eff7"))
neutral96 = _define_token(QColor("#f7f2fa"))
neutral98 = _define_token(QColor("#fef7ff"))
neutral99 = _define_token(QColor("#fffbff"))
primary0 = _define_token(QColor("#000000"))
primary10 = _define_token(QColor("#21005d"))
primary100 = _define_token(QColor("#ffffff"))
primary20 = _define_token(QColor("#381e72"))
primary30 = _define_token(QColor("#4f378b"))
primary40 = _define_token(QColor("#6750a4"))
primary50 = _define_token(QColor("#7f67be"))
primary60 = _define_token(QColor("#9a82db"))
primary70 = _define_token(QColor("#b69df8"))
primary80 = _define_token(QColor("#d0bcff"))
primary90 = _define_token(QColor("#eaddff"))
primary95 = _define_token(QColor("#f6edff"))
primary99 = _define_token(QColor("#fffbfe"))
secondary0 = _define_token(QColor("#000000"))
secondary10 = _define_token(QColor("#1d192b"))
secondary100 = _define_token(QColor("#ffffff"))
secondary20 = _define_token(QColor("#332d41"))
secondary30 = _define_token(QColor("#4a4458"))
secondary40 = _define_token(QColor("#625b71"))
secondary50 = _define_token(QColor("#7a7289"))
secondary60 = _define_token(QColor("#958da5"))
secondary70 = _define_token(QColor("#b0a7c0"))
secondary80 = _define_token(QColor("#ccc2dc"))
secondary90 = _define_token(QColor("#e8def8"))
secondary95 = _define_token(QColor("#f6edff"))
secondary99 = _define_token(QColor("#fffbfe"))
tertiary0 = _define_token(QColor("#000000"))
tertiary10 = _define_token(QColor("#31111d"))
tertiary100 = _define_token(QColor("#ffffff"))
tertiary20 = _define_token(QColor("#492532"))
tertiary30 = _define_token(QColor("#633b48"))
tertiary40 = _define_token(QColor("#7d5260"))
tertiary50 = _define_token(QColor("#986977"))
tertiary60 = _define_token(QColor("#b58392"))
tertiary70 = _define_token(QColor("#d29dac"))
tertiary80 = _define_token(QColor("#efb8c8"))
tertiary90 = _define_token(QColor("#ffd8e4"))
tertiary95 = _define_token(QColor("#ffecf1"))
tertiary99 = _define_token(QColor("#fffbfa"))
white = _define_token(QColor("#ffffff"))
