"""Design tokens for md.comp.assist-chip."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_height = _define_token(32)
container_shape = _define_token("md.sys.shape.corner.small")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
disabled_label_text_color = _define_token("md.sys.color.on-surface")
disabled_label_text_opacity = _define_token(0.38)
dragged_container_elevation = _define_token("md.sys.elevation.level4")
dragged_label_text_color = _define_token("md.sys.color.on-surface")
dragged_state_layer_color = _define_token("md.sys.color.on-surface")
dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
elevated_container_color = _define_token("md.sys.color.surface-container-low")
elevated_container_elevation = _define_token("md.sys.elevation.level1")
elevated_container_shadow_color = _define_token("md.sys.color.shadow")
elevated_disabled_container_color = _define_token("md.sys.color.on-surface")
elevated_disabled_container_elevation = _define_token("md.sys.elevation.level0")
elevated_disabled_container_opacity = _define_token(0.12)
elevated_focus_container_elevation = _define_token("md.sys.elevation.level1")
elevated_hover_container_elevation = _define_token("md.sys.elevation.level2")
elevated_pressed_container_elevation = _define_token("md.sys.elevation.level1")
flat_container_elevation = _define_token("md.sys.elevation.level0")
flat_disabled_outline_color = _define_token("md.sys.color.on-surface")
flat_disabled_outline_opacity = _define_token(0.12)
flat_focus_outline_color = _define_token("md.sys.color.on-surface")
flat_outline_color = _define_token("md.sys.color.outline-variant")
flat_outline_width = _define_token(1)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_label_text_color = _define_token("md.sys.color.on-surface")
focus_state_layer_color = _define_token("md.sys.color.on-surface")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_label_text_color = _define_token("md.sys.color.on-surface")
hover_state_layer_color = _define_token("md.sys.color.on-surface")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
label_text_color = _define_token("md.sys.color.on-surface")
label_text_font = _define_token("md.sys.typescale.label-large.font")
label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
label_text_size = _define_token("md.sys.typescale.label-large.size")
label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
label_text_weight = _define_token("md.sys.typescale.label-large.weight")
pressed_label_text_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
with_icon_disabled_icon_color = _define_token("md.sys.color.on-surface")
with_icon_disabled_icon_opacity = _define_token(0.38)
with_icon_dragged_icon_color = _define_token("md.sys.color.primary")
with_icon_focus_icon_color = _define_token("md.sys.color.primary")
with_icon_hover_icon_color = _define_token("md.sys.color.primary")
with_icon_icon_color = _define_token("md.sys.color.primary")
with_icon_icon_size = _define_token(18)
with_icon_pressed_icon_color = _define_token("md.sys.color.primary")
