"""Design tokens for md.comp.bottom-app-bar."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_color = _define_token("md.sys.color.surface-container")
container_elevation = _define_token("md.sys.elevation.level2")
container_height = _define_token(80)
container_shape = _define_token("md.sys.shape.corner.none")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
with_fab_container_height = _define_token(72)
