"""Design tokens for md.comp.filled-tonal-icon-button."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_color = _define_token("md.sys.color.secondary-container")
container_height = _define_token(40)
container_shape = _define_token("md.sys.shape.corner.full")
container_size = _define_token(40)
container_width = _define_token(40)
disabled_container_color = _define_token("md.sys.color.on-surface")
disabled_container_opacity = _define_token(0.12)
disabled_icon_color = _define_token("md.sys.color.on-surface")
disabled_icon_opacity = _define_token(0.38)
focus_icon_color = _define_token("md.sys.color.on-secondary-container")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_icon_color = _define_token("md.sys.color.on-secondary-container")
hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
icon_color = _define_token("md.sys.color.on-secondary-container")
icon_size = _define_token(24)
pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
selected_container_color = _define_token("md.sys.color.secondary-container")
toggle_selected_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_icon_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
toggle_selected_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
toggle_unselected_focus_icon_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_hover_icon_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_icon_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_pressed_icon_color = _define_token("md.sys.color.on-surface-variant")
toggle_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
unselected_container_color = _define_token("md.sys.color.surface-container-highest")
