"""Design tokens for md.comp.secondary-navigation-tab."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.primary")
active_indicator_height = _define_token(2)
active_label_text_color = _define_token("md.sys.color.on-surface")
container_color = _define_token("md.sys.color.surface")
container_elevation = _define_token("md.sys.elevation.level0")
container_height = _define_token(48)
container_shadow_color = _define_token("md.sys.color.shadow")
container_shape = _define_token("md.sys.shape.corner.none")
divider_color = _define_token("md.sys.color.surface-variant")
divider_height = _define_token(1)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.inner-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_label_text_color = _define_token("md.sys.color.on-surface")
focus_state_layer_color = _define_token("md.sys.color.on-surface")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_label_text_color = _define_token("md.sys.color.on-surface")
hover_state_layer_color = _define_token("md.sys.color.on-surface")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
inactive_label_text_color = _define_token("md.sys.color.on-surface-variant")
label_text_font = _define_token("md.sys.typescale.title-small.font")
label_text_line_height = _define_token("md.sys.typescale.title-small.line-height")
label_text_size = _define_token("md.sys.typescale.title-small.size")
label_text_tracking = _define_token("md.sys.typescale.title-small.tracking")
label_text_weight = _define_token("md.sys.typescale.title-small.weight")
pressed_label_text_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
with_icon_active_icon_color = _define_token("md.sys.color.on-surface")
with_icon_focus_icon_color = _define_token("md.sys.color.on-surface")
with_icon_hover_icon_color = _define_token("md.sys.color.on-surface")
with_icon_icon_size = _define_token(24)
with_icon_inactive_icon_color = _define_token("md.sys.color.on-surface-variant")
with_icon_pressed_icon_color = _define_token("md.sys.color.on-surface")
