"""Design tokens for md.comp.extended-fab."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

branded_container_color = _define_token("md.sys.color.surface-container-high")
branded_container_elevation = _define_token("md.sys.elevation.level3")
branded_container_height = _define_token(56)
branded_container_shadow_color = _define_token("md.sys.color.shadow")
branded_container_shape = _define_token("md.sys.shape.corner.large")
branded_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
branded_focus_container_elevation = _define_token("md.sys.elevation.level3")
branded_focus_indicator_color = _define_token("md.sys.color.secondary")
branded_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
branded_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
branded_focus_label_text_color = _define_token("md.sys.color.primary")
branded_focus_state_layer_color = _define_token("md.sys.color.primary")
branded_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
branded_hover_container_elevation = _define_token("md.sys.elevation.level4")
branded_hover_label_text_color = _define_token("md.sys.color.primary")
branded_hover_state_layer_color = _define_token("md.sys.color.primary")
branded_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
branded_icon_size = _define_token(36)
branded_label_text_color = _define_token("md.sys.color.on-surface")
branded_label_text_font = _define_token("md.sys.typescale.label-large.font")
branded_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
branded_label_text_size = _define_token("md.sys.typescale.label-large.size")
branded_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
branded_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
branded_lowered_container_color = _define_token("md.sys.color.surface-container-low")
branded_lowered_container_elevation = _define_token("md.sys.elevation.level1")
branded_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
branded_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
branded_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
branded_pressed_container_elevation = _define_token("md.sys.elevation.level3")
branded_pressed_label_text_color = _define_token("md.sys.color.primary")
branded_pressed_state_layer_color = _define_token("md.sys.color.primary")
branded_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
primary_container_color = _define_token("md.sys.color.primary-container")
primary_container_elevation = _define_token("md.sys.elevation.level3")
primary_container_height = _define_token(56)
primary_container_shadow_color = _define_token("md.sys.color.shadow")
primary_container_shape = _define_token("md.sys.shape.corner.large")
primary_focus_container_elevation = _define_token("md.sys.elevation.level3")
primary_focus_icon_color = _define_token("md.sys.color.on-primary-container")
primary_focus_indicator_color = _define_token("md.sys.color.secondary")
primary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
primary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
primary_focus_label_text_color = _define_token("md.sys.color.on-primary-container")
primary_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
primary_hover_container_elevation = _define_token("md.sys.elevation.level4")
primary_hover_icon_color = _define_token("md.sys.color.on-primary-container")
primary_hover_label_text_color = _define_token("md.sys.color.on-primary-container")
primary_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
primary_icon_color = _define_token("md.sys.color.on-primary-container")
primary_icon_size = _define_token(24)
primary_label_text_color = _define_token("md.sys.color.on-primary-container")
primary_label_text_font = _define_token("md.sys.typescale.label-large.font")
primary_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
primary_label_text_size = _define_token("md.sys.typescale.label-large.size")
primary_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
primary_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
primary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
primary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
primary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
primary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
primary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
primary_pressed_icon_color = _define_token("md.sys.color.on-primary-container")
primary_pressed_label_text_color = _define_token("md.sys.color.on-primary-container")
primary_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
secondary_container_color = _define_token("md.sys.color.secondary-container")
secondary_container_elevation = _define_token("md.sys.elevation.level3")
secondary_container_height = _define_token(56)
secondary_container_shadow_color = _define_token("md.sys.color.shadow")
secondary_container_shape = _define_token("md.sys.shape.corner.large")
secondary_focus_container_elevation = _define_token("md.sys.elevation.level3")
secondary_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_focus_indicator_color = _define_token("md.sys.color.secondary")
secondary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
secondary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
secondary_focus_label_text_color = _define_token("md.sys.color.on-secondary-container")
secondary_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
secondary_hover_container_elevation = _define_token("md.sys.elevation.level4")
secondary_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_hover_label_text_color = _define_token("md.sys.color.on-secondary-container")
secondary_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
secondary_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_icon_size = _define_token(24)
secondary_label_text_color = _define_token("md.sys.color.on-secondary-container")
secondary_label_text_font = _define_token("md.sys.typescale.label-large.font")
secondary_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
secondary_label_text_size = _define_token("md.sys.typescale.label-large.size")
secondary_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
secondary_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
secondary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
secondary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
secondary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
secondary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
secondary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
secondary_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_pressed_label_text_color = _define_token("md.sys.color.on-secondary-container")
secondary_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
surface_container_color = _define_token("md.sys.color.surface-container-high")
surface_container_elevation = _define_token("md.sys.elevation.level3")
surface_container_height = _define_token(56)
surface_container_shadow_color = _define_token("md.sys.color.shadow")
surface_container_shape = _define_token("md.sys.shape.corner.large")
surface_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
surface_focus_container_elevation = _define_token("md.sys.elevation.level3")
surface_focus_icon_color = _define_token("md.sys.color.primary")
surface_focus_indicator_color = _define_token("md.sys.color.secondary")
surface_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
surface_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
surface_focus_label_text_color = _define_token("md.sys.color.primary")
surface_focus_state_layer_color = _define_token("md.sys.color.primary")
surface_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
surface_hover_container_elevation = _define_token("md.sys.elevation.level4")
surface_hover_icon_color = _define_token("md.sys.color.primary")
surface_hover_label_text_color = _define_token("md.sys.color.primary")
surface_hover_state_layer_color = _define_token("md.sys.color.primary")
surface_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
surface_icon_color = _define_token("md.sys.color.primary")
surface_icon_size = _define_token(24)
surface_label_text_color = _define_token("md.sys.color.primary")
surface_label_text_font = _define_token("md.sys.typescale.label-large.font")
surface_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
surface_label_text_size = _define_token("md.sys.typescale.label-large.size")
surface_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
surface_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
surface_lowered_container_color = _define_token("md.sys.color.surface-container-low")
surface_lowered_container_elevation = _define_token("md.sys.elevation.level1")
surface_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
surface_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
surface_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
surface_pressed_container_elevation = _define_token("md.sys.elevation.level3")
surface_pressed_icon_color = _define_token("md.sys.color.primary")
surface_pressed_label_text_color = _define_token("md.sys.color.primary")
surface_pressed_state_layer_color = _define_token("md.sys.color.primary")
surface_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
tertiary_container_color = _define_token("md.sys.color.tertiary-container")
tertiary_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_container_height = _define_token(56)
tertiary_container_shadow_color = _define_token("md.sys.color.shadow")
tertiary_container_shape = _define_token("md.sys.shape.corner.large")
tertiary_focus_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_focus_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_focus_indicator_color = _define_token("md.sys.color.secondary")
tertiary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
tertiary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
tertiary_focus_label_text_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
tertiary_hover_container_elevation = _define_token("md.sys.elevation.level4")
tertiary_hover_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_hover_label_text_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
tertiary_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_icon_size = _define_token(24)
tertiary_label_text_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_label_text_font = _define_token("md.sys.typescale.label-large.font")
tertiary_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
tertiary_label_text_size = _define_token("md.sys.typescale.label-large.size")
tertiary_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
tertiary_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
tertiary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
tertiary_lowered_presed_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_pressed_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_pressed_label_text_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
