"""Design tokens for md.comp.progress-indicator."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_track_space = _define_token(4)
active_indicator_color = _define_token("md.sys.color.primary")
active_indicator_shape = _define_token("md.sys.shape.corner.full")
active_indicator_thickness = _define_token(4)
stop_indicator_color = _define_token("md.sys.color.primary")
stop_indicator_shape = _define_token(4)
stop_indicator_size = _define_token(4)
track_color = _define_token("md.sys.color.secondary-container")
track_shape = _define_token("md.sys.shape.corner.full")
track_thickness = _define_token(4)
