"""Design tokens for md.comp.linear-progress-indicator."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.primary")
active_indicator_height = _define_token(4)
active_indicator_shape = _define_token("md.sys.shape.corner.none")
four_color_active_indicator_four_color = _define_token("md.sys.color.tertiary-container")
four_color_active_indicator_one_color = _define_token("md.sys.color.primary")
four_color_active_indicator_three_color = _define_token("md.sys.color.tertiary")
four_color_active_indicator_two_color = _define_token("md.sys.color.primary-container")
track_color = _define_token("md.sys.color.surface-container-highest")
track_height = _define_token(4)
track_shape = _define_token("md.sys.shape.corner.none")
