"""Design tokens for md.comp.slider."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_container_opacity = _define_token(1.0)
active_handle_height = _define_token(44)
active_handle_leading_space = _define_token(6)
active_handle_padding = _define_token(6)
active_handle_shape = _define_token("md.sys.shape.corner.full")
active_handle_trailing_space = _define_token(6)
active_handle_width = _define_token(4)
active_stop_indicator_container_color = _define_token("md.sys.color.on-primary")
active_stop_indicator_container_opacity = _define_token(1.0)
active_track_color = _define_token("md.sys.color.primary")
active_track_height = _define_token(16)
active_track_shape = _define_token("md.sys.shape.corner.full")
active_track_shape_leading = _define_token("md.sys.shape.corner.full")
active_track_shape_trailing = _define_token("SHAPE_FAMILY_ROUNDED_CORNERS")
disabled_active_stop_indicator_container_color = _define_token("md.sys.color.inverse-on-surface")
disabled_active_track_color = _define_token("md.sys.color.on-surface")
disabled_active_track_opacity = _define_token(0.38)
disabled_handle_color = _define_token("md.sys.color.on-surface")
disabled_handle_elevation = _define_token("md.sys.elevation.level0")
disabled_handle_opacity = _define_token(0.38)
disabled_handle_width = _define_token(4)
disabled_inactive_stop_indicator_container_color = _define_token("md.sys.color.on-surface")
disabled_inactive_track_color = _define_token("md.sys.color.on-surface")
disabled_inactive_track_opacity = _define_token(0.12)
disabled_stop_indicator_color = _define_token("md.sys.color.on-surface")
disabled_stop_indicator_color_selected = _define_token("md.sys.color.inverse-on-surface")
disabled_stop_indicator_container_color = _define_token("md.sys.color.on-surface")
disabled_stop_indicator_container_opacity = _define_token(0.38)
focus_active_track_color = _define_token("md.sys.color.primary")
focus_handle_color = _define_token("md.sys.color.primary")
focus_handle_width = _define_token(2)
focus_inactive_track_color = _define_token("md.sys.color.secondary-container")
focus_state_layer_color = _define_token("md.sys.color.primary")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
focus_stop_color = _define_token("md.sys.color.primary")
handle_color = _define_token("md.sys.color.primary")
handle_elevation = _define_token("md.sys.elevation.level1")
handle_height = _define_token(44)
handle_shadow_color = _define_token("md.sys.color.shadow")
handle_shape = _define_token("md.sys.shape.corner.full")
handle_width = _define_token(4)
hover_handle_color = _define_token("md.sys.color.primary")
hover_handle_width = _define_token(4)
hover_state_layer_color = _define_token("md.sys.color.primary")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
hover_stop_color = _define_token("md.sys.color.primary")
inactive_container_opacity = _define_token(1.0)
inactive_stop_indicator_container_color = _define_token("md.sys.color.on-secondary-container")
inactive_stop_indicator_container_opacity = _define_token(1.0)
inactive_track_color = _define_token("md.sys.color.secondary-container")
inactive_track_height = _define_token(16)
inactive_track_shape = _define_token("md.sys.shape.corner.full")
label_container_color = _define_token("md.sys.color.primary")
label_container_elevation = _define_token("md.sys.elevation.level0")
label_container_height = _define_token(28)
label_label_text_color = _define_token("md.sys.color.inverse-on-surface")
label_label_text_font = _define_token("md.sys.typescale.label-medium.font")
label_label_text_font_size = _define_token("md.sys.typescale.label-medium.size")
label_label_text_line_height = _define_token("md.sys.typescale.label-medium.line-height")
label_label_text_size = _define_token("md.sys.typescale.label-medium.size")
label_label_text_tracking = _define_token("md.sys.typescale.label-medium.tracking")
label_label_text_weight = _define_token("md.sys.typescale.label-medium.weight")
pressed_active_track_color = _define_token("md.sys.color.primary")
pressed_handle_color = _define_token("md.sys.color.primary")
pressed_handle_width = _define_token(2)
pressed_inactive_track_color = _define_token("md.sys.color.secondary-container")
pressed_state_layer_color = _define_token("md.sys.color.primary")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
pressed_stop_color = _define_token("md.sys.color.primary")
slider_active_handle_color = _define_token("md.sys.color.primary")
state_layer_size = _define_token(40)
stop_indicator_color = _define_token("md.sys.color.on-secondary-container")
stop_indicator_color_selected = _define_token("md.sys.color.on-primary")
stop_indicator_shape = _define_token("md.sys.shape.corner.full")
stop_indicator_size = _define_token(4)
stop_indicator_trailing_space = _define_token(6)
track_elevation = _define_token("md.sys.elevation.level0")
value_indicator_active_bottom_space = _define_token(12)
value_indicator_container_color = _define_token("md.sys.color.inverse-surface")
value_indicator_label_label_text_color = _define_token("md.sys.color.inverse-on-surface")
value_indicator_label_label_text_font = _define_token("md.sys.typescale.label-large.font")
value_indicator_label_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
value_indicator_label_label_text_size = _define_token("md.sys.typescale.label-large.size")
value_indicator_label_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
value_indicator_label_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
with_overlap_handle_outline_color = _define_token("md.sys.color.on-primary")
with_overlap_handle_outline_width = _define_token(1)
with_tick_marks_active_container_color = _define_token("md.sys.color.on-primary")
with_tick_marks_active_container_opacity = _define_token(0.38)
with_tick_marks_container_shape = _define_token("md.sys.shape.corner.full")
with_tick_marks_container_size = _define_token(2)
with_tick_marks_disabled_container_color = _define_token("md.sys.color.on-surface")
with_tick_marks_disabled_container_opacity = _define_token(0.38)
with_tick_marks_inactive_container_color = _define_token("md.sys.color.on-surface-variant")
with_tick_marks_inactive_container_opacity = _define_token(0.38)
