"""Design tokens for md.comp.search-view."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_color = _define_token("md.sys.color.surface-container-high")
container_elevation = _define_token("md.sys.elevation.level3")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
divider_color = _define_token("md.sys.color.outline")
docked_container_shape = _define_token("md.sys.shape.corner.extra-large")
docked_header_container_height = _define_token(56)
full_screen_container_shape = _define_token("md.sys.shape.corner.none")
full_screen_header_container_height = _define_token(72)
header_input_text_color = _define_token("md.sys.color.on-surface")
header_input_text_font = _define_token("md.sys.typescale.body-large.font")
header_input_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
header_input_text_size = _define_token("md.sys.typescale.body-large.size")
header_input_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
header_input_text_weight = _define_token("md.sys.typescale.body-large.weight")
header_leading_icon_color = _define_token("md.sys.color.on-surface")
header_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
header_supporting_text_font = _define_token("md.sys.typescale.body-large.font")
header_supporting_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
header_supporting_text_size = _define_token("md.sys.typescale.body-large.size")
header_supporting_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
header_supporting_text_weight = _define_token("md.sys.typescale.body-large.weight")
header_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
