"""Design tokens for md.comp.switch."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

disabled_handle_elevation = _define_token("md.sys.elevation.level0")
disabled_handle_opacity = _define_token(0.38)
disabled_selected_handle_color = _define_token("md.sys.color.surface")
disabled_selected_handle_opacity = _define_token(1.0)
disabled_selected_icon_color = _define_token("md.sys.color.on-surface")
disabled_selected_icon_opacity = _define_token(0.38)
disabled_selected_track_color = _define_token("md.sys.color.on-surface")
disabled_track_opacity = _define_token(0.12)
disabled_unselected_handle_color = _define_token("md.sys.color.on-surface")
disabled_unselected_handle_opacity = _define_token(0.38)
disabled_unselected_icon_color = _define_token("md.sys.color.surface-container-highest")
disabled_unselected_icon_opacity = _define_token(0.38)
disabled_unselected_track_color = _define_token("md.sys.color.surface-container-highest")
disabled_unselected_track_outline_color = _define_token("md.sys.color.on-surface")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
handle_elevation = _define_token("md.sys.elevation.level1")
handle_height = _define_token(20)
handle_shadow_color = _define_token("md.sys.color.shadow")
handle_shape = _define_token("md.sys.shape.corner.full")
handle_width = _define_token(20)
pressed_handle_height = _define_token(28)
pressed_handle_width = _define_token(28)
selected_focus_handle_color = _define_token("md.sys.color.primary-container")
selected_focus_icon_color = _define_token("md.sys.color.on-primary-container")
selected_focus_state_layer_color = _define_token("md.sys.color.primary")
selected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
selected_focus_track_color = _define_token("md.sys.color.primary")
selected_handle_color = _define_token("md.sys.color.on-primary")
selected_handle_height = _define_token(24)
selected_handle_width = _define_token(24)
selected_hover_handle_color = _define_token("md.sys.color.primary-container")
selected_hover_icon_color = _define_token("md.sys.color.on-primary-container")
selected_hover_state_layer_color = _define_token("md.sys.color.primary")
selected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
selected_hover_track_color = _define_token("md.sys.color.primary")
selected_icon_color = _define_token("md.sys.color.on-primary-container")
selected_icon_size = _define_token(16)
selected_pressed_handle_color = _define_token("md.sys.color.primary-container")
selected_pressed_icon_color = _define_token("md.sys.color.on-primary-container")
selected_pressed_state_layer_color = _define_token("md.sys.color.primary")
selected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
selected_pressed_track_color = _define_token("md.sys.color.primary")
selected_track_color = _define_token("md.sys.color.primary")
state_layer_shape = _define_token("md.sys.shape.corner.full")
state_layer_size = _define_token(40)
track_height = _define_token(32)
track_outline_width = _define_token(2)
track_shape = _define_token("md.sys.shape.corner.full")
track_width = _define_token(52)
unselected_focus_handle_color = _define_token("md.sys.color.on-surface-variant")
unselected_focus_icon_color = _define_token("md.sys.color.surface-container-highest")
unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface")
unselected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
unselected_focus_track_color = _define_token("md.sys.color.surface-container-highest")
unselected_focus_track_outline_color = _define_token("md.sys.color.outline")
unselected_handle_color = _define_token("md.sys.color.outline")
unselected_handle_height = _define_token(16)
unselected_handle_width = _define_token(16)
unselected_hover_handle_color = _define_token("md.sys.color.on-surface-variant")
unselected_hover_icon_color = _define_token("md.sys.color.surface-container-highest")
unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface")
unselected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
unselected_hover_track_color = _define_token("md.sys.color.surface-container-highest")
unselected_hover_track_outline_color = _define_token("md.sys.color.outline")
unselected_icon_color = _define_token("md.sys.color.surface-container-highest")
unselected_icon_size = _define_token(16)
unselected_pressed_handle_color = _define_token("md.sys.color.on-surface-variant")
unselected_pressed_icon_color = _define_token("md.sys.color.surface-container-highest")
unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
unselected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
unselected_pressed_track_color = _define_token("md.sys.color.surface-container-highest")
unselected_pressed_track_outline_color = _define_token("md.sys.color.outline")
unselected_track_color = _define_token("md.sys.color.surface-container-highest")
unselected_track_outline_color = _define_token("md.sys.color.outline")
with_icon_handle_height = _define_token(24)
with_icon_handle_width = _define_token(24)
