"""Design tokens for md.comp.filled-card."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_color = _define_token("md.sys.color.surface-container-highest")
container_elevation = _define_token("md.sys.elevation.level0")
container_shadow_color = _define_token("md.sys.color.shadow")
container_shape = _define_token("md.sys.shape.corner.medium")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
disabled_container_color = _define_token("md.sys.color.surface-variant")
disabled_container_elevation = _define_token("md.sys.elevation.level0")
disabled_container_opacity = _define_token(0.38)
dragged_container_elevation = _define_token("md.sys.elevation.level3")
dragged_state_layer_color = _define_token("md.sys.color.on-surface")
dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
focus_container_elevation = _define_token("md.sys.elevation.level0")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_state_layer_color = _define_token("md.sys.color.on-surface")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_container_elevation = _define_token("md.sys.elevation.level1")
hover_state_layer_color = _define_token("md.sys.color.on-surface")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
icon_color = _define_token("md.sys.color.primary")
icon_size = _define_token(24)
pressed_container_elevation = _define_token("md.sys.elevation.level0")
pressed_state_layer_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
