"""Design tokens for md.comp.filled-text-field."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.on-surface-variant")
active_indicator_height = _define_token(1)
caret_color = _define_token("md.sys.color.primary")
container_color = _define_token("md.sys.color.surface-container-highest")
container_height = _define_token(56)
container_shape = _define_token("md.sys.shape.corner.extra-small.top")
disabled_active_indicator_color = _define_token("md.sys.color.on-surface")
disabled_active_indicator_height = _define_token(1)
disabled_active_indicator_opacity = _define_token(0.38)
disabled_container_color = _define_token("md.sys.color.on-surface")
disabled_container_opacity = _define_token(0.04)
disabled_input_text_color = _define_token("md.sys.color.on-surface")
disabled_input_text_opacity = _define_token(0.38)
disabled_label_text_color = _define_token("md.sys.color.on-surface")
disabled_label_text_opacity = _define_token(0.38)
disabled_leading_icon_color = _define_token("md.sys.color.on-surface")
disabled_leading_icon_opacity = _define_token(0.38)
disabled_supporting_text_color = _define_token("md.sys.color.on-surface")
disabled_supporting_text_opacity = _define_token(0.38)
disabled_trailing_icon_color = _define_token("md.sys.color.on-surface")
disabled_trailing_icon_opacity = _define_token(0.38)
error_active_indicator_color = _define_token("md.sys.color.error")
error_focus_active_indicator_color = _define_token("md.sys.color.error")
error_focus_caret_color = _define_token("md.sys.color.error")
error_focus_input_text_color = _define_token("md.sys.color.on-surface")
error_focus_label_text_color = _define_token("md.sys.color.error")
error_focus_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
error_focus_supporting_text_color = _define_token("md.sys.color.error")
error_focus_trailing_icon_color = _define_token("md.sys.color.error")
error_hover_active_indicator_color = _define_token("md.sys.color.on-error-container")
error_hover_input_text_color = _define_token("md.sys.color.on-surface")
error_hover_label_text_color = _define_token("md.sys.color.on-error-container")
error_hover_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
error_hover_state_layer_color = _define_token("md.sys.color.on-surface")
error_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
error_hover_supporting_text_color = _define_token("md.sys.color.error")
error_hover_trailing_icon_color = _define_token("md.sys.color.on-error-container")
error_input_text_color = _define_token("md.sys.color.on-surface")
error_label_text_color = _define_token("md.sys.color.error")
error_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
error_supporting_text_color = _define_token("md.sys.color.error")
error_trailing_icon_color = _define_token("md.sys.color.error")
focus_active_indicator_color = _define_token("md.sys.color.primary")
focus_active_indicator_height = _define_token(2)
focus_active_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_input_text_color = _define_token("md.sys.color.on-surface")
focus_label_text_color = _define_token("md.sys.color.primary")
focus_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
focus_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
focus_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
hover_active_indicator_color = _define_token("md.sys.color.on-surface")
hover_active_indicator_height = _define_token(1)
hover_input_text_color = _define_token("md.sys.color.on-surface")
hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
hover_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
hover_state_layer_color = _define_token("md.sys.color.on-surface")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
hover_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
hover_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
input_text_color = _define_token("md.sys.color.on-surface")
input_text_font = _define_token("md.sys.typescale.body-large.font")
input_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
input_text_placeholder_color = _define_token("md.sys.color.on-surface-variant")
input_text_prefix_color = _define_token("md.sys.color.on-surface-variant")
input_text_size = _define_token("md.sys.typescale.body-large.size")
input_text_suffix_color = _define_token("md.sys.color.on-surface-variant")
input_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
input_text_weight = _define_token("md.sys.typescale.body-large.weight")
label_text_color = _define_token("md.sys.color.on-surface-variant")
label_text_font = _define_token("md.sys.typescale.body-large.font")
label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
label_text_populated_line_height = _define_token("md.sys.typescale.body-small.line-height")
label_text_populated_size = _define_token("md.sys.typescale.body-small.size")
label_text_size = _define_token("md.sys.typescale.body-large.size")
label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
label_text_weight = _define_token("md.sys.typescale.body-large.weight")
leading_icon_color = _define_token("md.sys.color.on-surface-variant")
leading_icon_size = _define_token(24)
supporting_text_color = _define_token("md.sys.color.on-surface-variant")
supporting_text_font = _define_token("md.sys.typescale.body-small.font")
supporting_text_line_height = _define_token("md.sys.typescale.body-small.line-height")
supporting_text_size = _define_token("md.sys.typescale.body-small.size")
supporting_text_tracking = _define_token("md.sys.typescale.body-small.tracking")
supporting_text_weight = _define_token("md.sys.typescale.body-small.weight")
trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
trailing_icon_size = _define_token(24)
