"""Design tokens for md.comp.primary-navigation-tab."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.primary")
active_indicator_height = _define_token(3)
active_indicator_shape = _define_token("SHAPE_FAMILY_ROUNDED_CORNERS")
active_focus_state_layer_color = _define_token("md.sys.color.primary")
active_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
active_hover_state_layer_color = _define_token("md.sys.color.primary")
active_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
active_pressed_state_layer_color = _define_token("md.sys.color.primary")
active_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
container_color = _define_token("md.sys.color.surface")
container_elevation = _define_token("md.sys.elevation.level0")
container_height = _define_token(48)
container_shape = _define_token("md.sys.shape.corner.none")
divider_color = _define_token("md.sys.color.surface-variant")
divider_height = _define_token(1)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.inner-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
inactive_focus_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
inactive_hover_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
inactive_pressed_state_layer_color = _define_token("md.sys.color.primary")
inactive_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
with_icon_and_label_text_container_height = _define_token(64)
with_icon_active_focus_icon_color = _define_token("md.sys.color.primary")
with_icon_active_hover_icon_color = _define_token("md.sys.color.primary")
with_icon_active_icon_color = _define_token("md.sys.color.primary")
with_icon_active_pressed_icon_color = _define_token("md.sys.color.primary")
with_icon_icon_size = _define_token(24)
with_icon_inactive_focus_icon_color = _define_token("md.sys.color.on-surface")
with_icon_inactive_hover_icon_color = _define_token("md.sys.color.on-surface")
with_icon_inactive_icon_color = _define_token("md.sys.color.on-surface-variant")
with_icon_inactive_pressed_icon_color = _define_token("md.sys.color.on-surface")
with_label_text_active_focus_label_text_color = _define_token("md.sys.color.primary")
with_label_text_active_hover_label_text_color = _define_token("md.sys.color.primary")
with_label_text_active_label_text_color = _define_token("md.sys.color.primary")
with_label_text_active_pressed_label_text_color = _define_token("md.sys.color.primary")
with_label_text_inactive_focus_label_text_color = _define_token("md.sys.color.on-surface")
with_label_text_inactive_hover_label_text_color = _define_token("md.sys.color.on-surface")
with_label_text_inactive_label_text_color = _define_token("md.sys.color.on-surface-variant")
with_label_text_inactive_pressed_label_text_color = _define_token("md.sys.color.on-surface")
with_label_text_label_text_font = _define_token("md.sys.typescale.title-small.font")
with_label_text_label_text_line_height = _define_token("md.sys.typescale.title-small.line-height")
with_label_text_label_text_size = _define_token("md.sys.typescale.title-small.size")
with_label_text_label_text_tracking = _define_token("md.sys.typescale.title-small.tracking")
with_label_text_label_text_weight = _define_token("md.sys.typescale.title-small.weight")
