"""Design tokens for md.comp.time-input."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_color = _define_token("md.sys.color.surface-container-high")
container_elevation = _define_token("md.sys.elevation.level3")
container_shape = _define_token("md.sys.shape.corner.extra-large")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
headline_color = _define_token("md.sys.color.on-surface-variant")
headline_font = _define_token("md.sys.typescale.label-medium.font")
headline_line_height = _define_token("md.sys.typescale.label-medium.line-height")
headline_size = _define_token("md.sys.typescale.label-medium.size")
headline_tracking = _define_token("md.sys.typescale.label-medium.tracking")
headline_weight = _define_token("md.sys.typescale.label-medium.weight")
period_selector_container_height = _define_token(72)
period_selector_container_shape = _define_token("md.sys.shape.corner.small")
period_selector_container_width = _define_token(52)
period_selector_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
period_selector_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
period_selector_label_text_font = _define_token("md.sys.typescale.title-medium.font")
period_selector_label_text_line_height = _define_token("md.sys.typescale.title-medium.line-height")
period_selector_label_text_size = _define_token("md.sys.typescale.title-medium.size")
period_selector_label_text_tracking = _define_token("md.sys.typescale.title-medium.tracking")
period_selector_label_text_weight = _define_token("md.sys.typescale.title-medium.weight")
period_selector_outline_color = _define_token("md.sys.color.outline")
period_selector_outline_width = _define_token(1)
period_selector_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
period_selector_selected_container_color = _define_token("md.sys.color.tertiary-container")
period_selector_selected_focus_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_hover_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_pressed_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_unselected_focus_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_pressed_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
time_input_field_container_color = _define_token("md.sys.color.surface-container-highest")
time_input_field_container_height = _define_token(72)
time_input_field_container_shape = _define_token("md.sys.shape.corner.small")
time_input_field_container_width = _define_token(96)
time_input_field_focus_container_color = _define_token("md.sys.color.primary-container")
time_input_field_focus_label_text_color = _define_token("md.sys.color.on-primary-container")
time_input_field_focus_outline_color = _define_token("md.sys.color.primary")
time_input_field_focus_outline_width = _define_token(2)
time_input_field_hover_label_text_color = _define_token("md.sys.color.on-surface")
time_input_field_hover_state_layer_color = _define_token("md.sys.color.on-surface")
time_input_field_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
time_input_field_label_text_color = _define_token("md.sys.color.on-surface")
time_input_field_label_text_font = _define_token("md.sys.typescale.display-medium.font")
time_input_field_label_text_line_height = _define_token("md.sys.typescale.display-medium.line-height")
time_input_field_label_text_size = _define_token("md.sys.typescale.display-medium.size")
time_input_field_label_text_tracking = _define_token("md.sys.typescale.display-medium.tracking")
time_input_field_label_text_weight = _define_token("md.sys.typescale.display-medium.weight")
time_input_field_separator_color = _define_token("md.sys.color.on-surface")
time_input_field_separator_font = _define_token("md.sys.typescale.display-large.font")
time_input_field_separator_line_height = _define_token("md.sys.typescale.display-large.line-height")
time_input_field_separator_size = _define_token("md.sys.typescale.display-large.size")
time_input_field_separator_tracking = _define_token("md.sys.typescale.display-large.tracking")
time_input_field_separator_weight = _define_token("md.sys.typescale.display-large.weight")
time_input_field_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
time_input_field_supporting_text_font = _define_token("md.sys.typescale.body-small.font")
time_input_field_supporting_text_line_height = _define_token("md.sys.typescale.body-small.line-height")
time_input_field_supporting_text_size = _define_token("md.sys.typescale.body-small.size")
time_input_field_supporting_text_tracking = _define_token("md.sys.typescale.body-small.tracking")
time_input_field_supporting_text_weight = _define_token("md.sys.typescale.body-small.weight")
