"""Design tokens for md.comp.checkbox."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_height = _define_token(18)
container_shape = _define_token("md.sys.shape.corner.extra-extra-small")
container_size = _define_token(18)
container_width = _define_token(18)
disabled_selected_icon_color = _define_token("md.sys.color.primary")
disabled_selected_icon_opacity = _define_token(0.38)
disabled_unselected_icon_color = _define_token("md.sys.color.primary")
disabled_unselected_icon_opacity = _define_token(0.38)
error_focus_state_layer_color = _define_token("md.sys.color.error")
error_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
error_hover_state_layer_color = _define_token("md.sys.color.error")
error_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
error_pressed_state_layer_color = _define_token("md.sys.color.error")
error_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
icon_size = _define_token(18)
selected_container_color = _define_token("md.sys.color.primary")
selected_disabled_container_color = _define_token("md.sys.color.on-surface")
selected_disabled_container_opacity = _define_token(0.38)
selected_disabled_container_outline_width = _define_token(0)
selected_disabled_icon_color = _define_token("md.sys.color.surface")
selected_error_container_color = _define_token("md.sys.color.error")
selected_error_focus_container_color = _define_token("md.sys.color.error")
selected_error_focus_icon_color = _define_token("md.sys.color.on-error")
selected_error_focus_outline_width = _define_token(0)
selected_error_hover_container_color = _define_token("md.sys.color.error")
selected_error_hover_icon_color = _define_token("md.sys.color.on-error")
selected_error_hover_outline_width = _define_token(0)
selected_error_icon_color = _define_token("md.sys.color.on-error")
selected_error_pressed_container_color = _define_token("md.sys.color.error")
selected_error_pressed_icon_color = _define_token("md.sys.color.on-error")
selected_error_pressed_outline_width = _define_token(0)
selected_focus_container_color = _define_token("md.sys.color.primary")
selected_focus_icon_color = _define_token("md.sys.color.on-primary")
selected_focus_outline_width = _define_token(0)
selected_focus_state_layer_color = _define_token("md.sys.color.primary")
selected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
selected_hover_container_color = _define_token("md.sys.color.primary")
selected_hover_icon_color = _define_token("md.sys.color.on-primary")
selected_hover_outline_width = _define_token(0)
selected_hover_state_layer_color = _define_token("md.sys.color.primary")
selected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
selected_icon_color = _define_token("md.sys.color.on-primary")
selected_outline_width = _define_token(0)
selected_pressed_container_color = _define_token("md.sys.color.primary")
selected_pressed_icon_color = _define_token("md.sys.color.on-primary")
selected_pressed_outline_width = _define_token(0)
selected_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
selected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
state_layer_shape = _define_token("md.sys.shape.corner.full")
state_layer_size = _define_token(40)
unselected_disabled_container_opacity = _define_token(0.38)
unselected_disabled_outline_color = _define_token("md.sys.color.on-surface")
unselected_disabled_outline_width = _define_token(2)
unselected_error_focus_outline_color = _define_token("md.sys.color.error")
unselected_error_focus_outline_width = _define_token(2)
unselected_error_hover_outline_color = _define_token("md.sys.color.error")
unselected_error_hover_outline_width = _define_token(2)
unselected_error_outline_color = _define_token("md.sys.color.error")
unselected_error_pressed_outline_color = _define_token("md.sys.color.error")
unselected_error_pressed_outline_width = _define_token(2)
unselected_focus_icon_color = _define_token("md.sys.color.on-surface")
unselected_focus_outline_color = _define_token("md.sys.color.on-surface")
unselected_focus_outline_width = _define_token(2)
unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface")
unselected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
unselected_hover_icon_color = _define_token("md.sys.color.on-surface")
unselected_hover_outline_color = _define_token("md.sys.color.on-surface")
unselected_hover_outline_width = _define_token(2)
unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface")
unselected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
unselected_icon_color = _define_token("md.sys.color.on-surface")
unselected_outline_color = _define_token("md.sys.color.on-surface-variant")
unselected_outline_width = _define_token(2)
unselected_pressed_icon_color = _define_token("md.sys.color.on-surface")
unselected_pressed_outline_color = _define_token("md.sys.color.on-surface")
unselected_pressed_outline_width = _define_token(2)
unselected_pressed_state_layer_color = _define_token("md.sys.color.primary")
unselected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
