"""Design tokens for md.comp.text-button."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_elevation = _define_token("md.sys.elevation.level0")
container_height = _define_token(40)
container_shape = _define_token("md.sys.shape.corner.full")
disabled_label_text_color = _define_token("md.sys.color.on-surface")
disabled_label_text_opacity = _define_token(0.38)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_label_text_color = _define_token("md.sys.color.primary")
focus_state_layer_color = _define_token("md.sys.color.primary")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_label_text_color = _define_token("md.sys.color.primary")
hover_state_layer_color = _define_token("md.sys.color.primary")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
label_text_color = _define_token("md.sys.color.primary")
label_text_font = _define_token("md.sys.typescale.label-large.font")
label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
label_text_size = _define_token("md.sys.typescale.label-large.size")
label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
label_text_weight = _define_token("md.sys.typescale.label-large.weight")
pressed_label_text_color = _define_token("md.sys.color.primary")
pressed_state_layer_color = _define_token("md.sys.color.primary")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
with_icon_disabled_icon_color = _define_token("md.sys.color.on-surface")
with_icon_disabled_icon_opacity = _define_token(0.38)
with_icon_focus_icon_color = _define_token("md.sys.color.primary")
with_icon_hover_icon_color = _define_token("md.sys.color.primary")
with_icon_icon_color = _define_token("md.sys.color.primary")
with_icon_icon_size = _define_token(18)
with_icon_pressed_icon_color = _define_token("md.sys.color.primary")
