"""Design tokens for md.comp.fab."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

branded_container_color = _define_token("md.sys.color.surface-container-high")
branded_container_elevation = _define_token("md.sys.elevation.level3")
branded_container_height = _define_token(56)
branded_container_shadow_color = _define_token("md.sys.color.shadow")
branded_container_shape = _define_token("md.sys.shape.corner.large")
branded_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
branded_container_width = _define_token(56)
branded_focus_container_elevation = _define_token("md.sys.elevation.level3")
branded_focus_indicator_color = _define_token("md.sys.color.secondary")
branded_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
branded_focus_state_layer_color = _define_token("md.sys.color.primary")
branded_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
branded_hover_container_elevation = _define_token("md.sys.elevation.level4")
branded_hover_state_layer_color = _define_token("md.sys.color.primary")
branded_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
branded_icon_size = _define_token(36)
branded_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
branded_large_container_color = _define_token("md.sys.color.surface-container-high")
branded_large_container_elevation = _define_token("md.sys.elevation.level3")
branded_large_container_height = _define_token(96)
branded_large_container_shadow_color = _define_token("md.sys.color.shadow")
branded_large_container_shape = _define_token("md.sys.shape.corner.extra-large")
branded_large_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
branded_large_container_width = _define_token(96)
branded_large_focus_container_elevation = _define_token("md.sys.elevation.level3")
branded_large_focus_indicator_color = _define_token("md.sys.color.secondary")
branded_large_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
branded_large_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
branded_large_focus_state_layer_color = _define_token("md.sys.color.primary")
branded_large_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
branded_large_hover_container_elevation = _define_token("md.sys.elevation.level4")
branded_large_hover_state_layer_color = _define_token("md.sys.color.primary")
branded_large_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
branded_large_icon_color = _define_token("md.sys.color.on-secondary")
branded_large_icon_size = _define_token(48)
branded_large_lowered_container_color = _define_token("md.sys.color.surface-container-low")
branded_large_lowered_container_elevation = _define_token("md.sys.elevation.level1")
branded_large_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
branded_large_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
branded_large_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
branded_large_pressed_container_elevation = _define_token("md.sys.elevation.level3")
branded_large_pressed_state_layer_color = _define_token("md.sys.color.primary")
branded_large_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
branded_lowered_container_color = _define_token("md.sys.color.surface-container-low")
branded_lowered_container_elevation = _define_token("md.sys.elevation.level1")
branded_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
branded_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
branded_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
branded_pressed_container_elevation = _define_token("md.sys.elevation.level3")
branded_pressed_state_layer_color = _define_token("md.sys.color.primary")
branded_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
primary_container_color = _define_token("md.sys.color.primary-container")
primary_container_elevation = _define_token("md.sys.elevation.level3")
primary_container_height = _define_token(56)
primary_container_shadow_color = _define_token("md.sys.color.shadow")
primary_container_shape = _define_token("md.sys.shape.corner.large")
primary_container_width = _define_token(56)
primary_focus_container_elevation = _define_token("md.sys.elevation.level3")
primary_focus_icon_color = _define_token("md.sys.color.on-primary-container")
primary_focus_indicator_color = _define_token("md.sys.color.secondary")
primary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
primary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
primary_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
primary_hover_container_elevation = _define_token("md.sys.elevation.level4")
primary_hover_icon_color = _define_token("md.sys.color.on-primary-container")
primary_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
primary_icon_color = _define_token("md.sys.color.on-primary-container")
primary_icon_size = _define_token(24)
primary_large_container_color = _define_token("md.sys.color.primary-container")
primary_large_container_elevation = _define_token("md.sys.elevation.level3")
primary_large_container_height = _define_token(96)
primary_large_container_shadow_color = _define_token("md.sys.color.shadow")
primary_large_container_shape = _define_token("md.sys.shape.corner.extra-large")
primary_large_container_width = _define_token(96)
primary_large_focus_container_elevation = _define_token("md.sys.elevation.level3")
primary_large_focus_icon_color = _define_token("md.sys.color.on-primary-container")
primary_large_focus_indicator_color = _define_token("md.sys.color.secondary")
primary_large_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
primary_large_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
primary_large_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_large_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
primary_large_hover_container_elevation = _define_token("md.sys.elevation.level4")
primary_large_hover_icon_color = _define_token("md.sys.color.on-primary-container")
primary_large_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_large_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
primary_large_icon_color = _define_token("md.sys.color.on-primary-container")
primary_large_icon_size = _define_token(36)
primary_large_lowered_container_elevation = _define_token("md.sys.elevation.level1")
primary_large_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
primary_large_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
primary_large_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
primary_large_pressed_container_elevation = _define_token("md.sys.elevation.level3")
primary_large_pressed_icon_color = _define_token("md.sys.color.on-primary-container")
primary_large_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_large_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
primary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
primary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
primary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
primary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
primary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
primary_pressed_icon_color = _define_token("md.sys.color.on-primary-container")
primary_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
primary_small_container_color = _define_token("md.sys.color.primary-container")
primary_small_container_elevation = _define_token("md.sys.elevation.level3")
primary_small_container_height = _define_token(40)
primary_small_container_shadow_color = _define_token("md.sys.color.shadow")
primary_small_container_shape = _define_token("md.sys.shape.corner.medium")
primary_small_container_width = _define_token(40)
primary_small_focus_container_elevation = _define_token("md.sys.elevation.level3")
primary_small_focus_icon_color = _define_token("md.sys.color.on-primary-container")
primary_small_focus_indicator_color = _define_token("md.sys.color.secondary")
primary_small_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
primary_small_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
primary_small_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_small_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
primary_small_hover_container_elevation = _define_token("md.sys.elevation.level4")
primary_small_hover_icon_color = _define_token("md.sys.color.on-primary-container")
primary_small_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_small_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
primary_small_icon_color = _define_token("md.sys.color.on-primary-container")
primary_small_icon_size = _define_token(24)
primary_small_lowered_container_elevation = _define_token("md.sys.elevation.level1")
primary_small_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
primary_small_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
primary_small_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
primary_small_pressed_container_elevation = _define_token("md.sys.elevation.level3")
primary_small_pressed_icon_color = _define_token("md.sys.color.on-primary-container")
primary_small_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
primary_small_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
secondary_container_color = _define_token("md.sys.color.secondary-container")
secondary_container_elevation = _define_token("md.sys.elevation.level3")
secondary_container_height = _define_token(56)
secondary_container_shadow_color = _define_token("md.sys.color.shadow")
secondary_container_shape = _define_token("md.sys.shape.corner.large")
secondary_container_width = _define_token(56)
secondary_focus_container_elevation = _define_token("md.sys.elevation.level3")
secondary_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_focus_indicator_color = _define_token("md.sys.color.secondary")
secondary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
secondary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
secondary_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
secondary_hover_container_elevation = _define_token("md.sys.elevation.level4")
secondary_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
secondary_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_icon_size = _define_token(24)
secondary_large_container_color = _define_token("md.sys.color.secondary-container")
secondary_large_container_elevation = _define_token("md.sys.elevation.level3")
secondary_large_container_height = _define_token(96)
secondary_large_container_shadow_color = _define_token("md.sys.color.shadow")
secondary_large_container_shape = _define_token("md.sys.shape.corner.extra-large")
secondary_large_container_width = _define_token(96)
secondary_large_focus_container_elevation = _define_token("md.sys.elevation.level3")
secondary_large_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_focus_indicator_color = _define_token("md.sys.color.secondary")
secondary_large_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
secondary_large_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
secondary_large_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
secondary_large_hover_container_elevation = _define_token("md.sys.elevation.level4")
secondary_large_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
secondary_large_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_icon_size = _define_token(36)
secondary_large_lowered_container_elevation = _define_token("md.sys.elevation.level1")
secondary_large_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
secondary_large_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
secondary_large_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
secondary_large_pressed_container_elevation = _define_token("md.sys.elevation.level3")
secondary_large_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_large_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
secondary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
secondary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
secondary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
secondary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
secondary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
secondary_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
secondary_small_container_color = _define_token("md.sys.color.secondary-container")
secondary_small_container_elevation = _define_token("md.sys.elevation.level3")
secondary_small_container_height = _define_token(40)
secondary_small_container_shadow_color = _define_token("md.sys.color.shadow")
secondary_small_container_shape = _define_token("md.sys.shape.corner.medium")
secondary_small_container_width = _define_token(40)
secondary_small_focus_container_elevation = _define_token("md.sys.elevation.level3")
secondary_small_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_focus_indicator_color = _define_token("md.sys.color.secondary")
secondary_small_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
secondary_small_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
secondary_small_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
secondary_small_hover_container_elevation = _define_token("md.sys.elevation.level4")
secondary_small_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
secondary_small_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_icon_size = _define_token(24)
secondary_small_lowered_container_elevation = _define_token("md.sys.elevation.level1")
secondary_small_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
secondary_small_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
secondary_small_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
secondary_small_pressed_container_elevation = _define_token("md.sys.elevation.level3")
secondary_small_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
secondary_small_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
surface_container_color = _define_token("md.sys.color.surface-container-high")
surface_container_elevation = _define_token("md.sys.elevation.level3")
surface_container_height = _define_token(56)
surface_container_shadow_color = _define_token("md.sys.color.shadow")
surface_container_shape = _define_token("md.sys.shape.corner.large")
surface_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
surface_container_width = _define_token(56)
surface_focus_container_elevation = _define_token("md.sys.elevation.level3")
surface_focus_icon_color = _define_token("md.sys.color.primary")
surface_focus_indicator_color = _define_token("md.sys.color.secondary")
surface_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
surface_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
surface_focus_state_layer_color = _define_token("md.sys.color.primary")
surface_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
surface_hover_container_elevation = _define_token("md.sys.elevation.level4")
surface_hover_icon_color = _define_token("md.sys.color.primary")
surface_hover_state_layer_color = _define_token("md.sys.color.primary")
surface_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
surface_icon_color = _define_token("md.sys.color.primary")
surface_icon_size = _define_token(24)
surface_large_container_color = _define_token("md.sys.color.surface-container-high")
surface_large_container_elevation = _define_token("md.sys.elevation.level3")
surface_large_container_height = _define_token(96)
surface_large_container_shadow_color = _define_token("md.sys.color.shadow")
surface_large_container_shape = _define_token("md.sys.shape.corner.extra-large")
surface_large_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
surface_large_container_width = _define_token(96)
surface_large_focus_container_elevation = _define_token("md.sys.elevation.level3")
surface_large_focus_icon_color = _define_token("md.sys.color.primary")
surface_large_focus_indicator_color = _define_token("md.sys.color.secondary")
surface_large_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
surface_large_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
surface_large_focus_state_layer_color = _define_token("md.sys.color.primary")
surface_large_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
surface_large_hover_container_elevation = _define_token("md.sys.elevation.level4")
surface_large_hover_icon_color = _define_token("md.sys.color.primary")
surface_large_hover_state_layer_color = _define_token("md.sys.color.primary")
surface_large_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
surface_large_icon_color = _define_token("md.sys.color.primary")
surface_large_icon_size = _define_token(36)
surface_large_lowered_container_color = _define_token("md.sys.color.surface-container-low")
surface_large_lowered_container_elevation = _define_token("md.sys.elevation.level1")
surface_large_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
surface_large_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
surface_large_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
surface_large_pressed_container_elevation = _define_token("md.sys.elevation.level3")
surface_large_pressed_icon_color = _define_token("md.sys.color.primary")
surface_large_pressed_state_layer_color = _define_token("md.sys.color.primary")
surface_large_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
surface_lowered_container_color = _define_token("md.sys.color.surface-container-low")
surface_lowered_container_elevation = _define_token("md.sys.elevation.level1")
surface_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
surface_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
surface_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
surface_pressed_container_elevation = _define_token("md.sys.elevation.level3")
surface_pressed_icon_color = _define_token("md.sys.color.primary")
surface_pressed_state_layer_color = _define_token("md.sys.color.primary")
surface_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
surface_small_container_color = _define_token("md.sys.color.surface-container-high")
surface_small_container_elevation = _define_token("md.sys.elevation.level3")
surface_small_container_height = _define_token(40)
surface_small_container_shadow_color = _define_token("md.sys.color.shadow")
surface_small_container_shape = _define_token("md.sys.shape.corner.medium")
surface_small_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
surface_small_container_width = _define_token(40)
surface_small_focus_container_elevation = _define_token("md.sys.elevation.level3")
surface_small_focus_icon_color = _define_token("md.sys.color.primary")
surface_small_focus_indicator_color = _define_token("md.sys.color.secondary")
surface_small_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
surface_small_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
surface_small_focus_state_layer_color = _define_token("md.sys.color.primary")
surface_small_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
surface_small_hover_container_elevation = _define_token("md.sys.elevation.level4")
surface_small_hover_icon_color = _define_token("md.sys.color.primary")
surface_small_hover_state_layer_color = _define_token("md.sys.color.primary")
surface_small_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
surface_small_icon_color = _define_token("md.sys.color.primary")
surface_small_icon_size = _define_token(24)
surface_small_lowered_container_color = _define_token("md.sys.color.surface-container-low")
surface_small_lowered_container_elevation = _define_token("md.sys.elevation.level1")
surface_small_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
surface_small_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
surface_small_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
surface_small_pressed_container_elevation = _define_token("md.sys.elevation.level3")
surface_small_pressed_icon_color = _define_token("md.sys.color.primary")
surface_small_pressed_state_layer_color = _define_token("md.sys.color.primary")
surface_small_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
tertiary_container_color = _define_token("md.sys.color.tertiary-container")
tertiary_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_container_height = _define_token(56)
tertiary_container_shadow_color = _define_token("md.sys.color.shadow")
tertiary_container_shape = _define_token("md.sys.shape.corner.large")
tertiary_container_width = _define_token(56)
tertiary_focus_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_focus_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_focus_indicator_color = _define_token("md.sys.color.secondary")
tertiary_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
tertiary_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
tertiary_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
tertiary_hover_container_elevation = _define_token("md.sys.elevation.level4")
tertiary_hover_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
tertiary_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_icon_size = _define_token(24)
tertiary_large_container_color = _define_token("md.sys.color.tertiary-container")
tertiary_large_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_large_container_height = _define_token(96)
tertiary_large_container_shadow_color = _define_token("md.sys.color.shadow")
tertiary_large_container_shape = _define_token("md.sys.shape.corner.extra-large")
tertiary_large_container_width = _define_token(96)
tertiary_large_focus_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_large_focus_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_focus_indicator_color = _define_token("md.sys.color.secondary")
tertiary_large_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
tertiary_large_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
tertiary_large_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
tertiary_large_hover_container_elevation = _define_token("md.sys.elevation.level4")
tertiary_large_hover_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
tertiary_large_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_icon_size = _define_token(36)
tertiary_large_lowered_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_large_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_large_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
tertiary_large_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_large_pressed_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_large_pressed_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_large_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
tertiary_lowered_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
tertiary_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_pressed_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_pressed_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
tertiary_small_container_color = _define_token("md.sys.color.tertiary-container")
tertiary_small_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_small_container_height = _define_token(40)
tertiary_small_container_shadow_color = _define_token("md.sys.color.shadow")
tertiary_small_container_shape = _define_token("md.sys.shape.corner.medium")
tertiary_small_container_width = _define_token(40)
tertiary_small_focus_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_small_focus_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_focus_indicator_color = _define_token("md.sys.color.secondary")
tertiary_small_focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
tertiary_small_focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
tertiary_small_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
tertiary_small_hover_container_elevation = _define_token("md.sys.elevation.level4")
tertiary_small_hover_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
tertiary_small_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_icon_size = _define_token(24)
tertiary_small_lowered_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_small_lowered_focus_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_small_lowered_hover_container_elevation = _define_token("md.sys.elevation.level2")
tertiary_small_lowered_pressed_container_elevation = _define_token("md.sys.elevation.level1")
tertiary_small_pressed_container_elevation = _define_token("md.sys.elevation.level3")
tertiary_small_pressed_icon_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
tertiary_small_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
