"""Design tokens for md.comp.divider."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

color = _define_token("md.sys.color.outline-variant")
thickness = _define_token(1)
