"""Design tokens for md.comp.navigation-drawer."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.secondary-container")
active_indicator_height = _define_token(56)
active_indicator_shape = _define_token("md.sys.shape.corner.full")
active_indicator_width = _define_token(336)
active_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
active_focus_label_text_color = _define_token("md.sys.color.on-secondary-container")
active_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
active_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
active_hover_label_text_color = _define_token("md.sys.color.on-secondary-container")
active_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
active_icon_color = _define_token("md.sys.color.on-secondary-container")
active_label_text_color = _define_token("md.sys.color.on-secondary-container")
active_label_text_weight = _define_token("md.sys.typescale.label-large.weight.prominent")
active_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
active_pressed_label_text_color = _define_token("md.sys.color.on-secondary-container")
active_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
bottom_container_shape = _define_token("md.sys.shape.corner.large.top")
container_color = _define_token("md.sys.color.surface")
container_height = _define_token(1.0)
container_shape = _define_token("md.sys.shape.corner.large.end")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
container_width = _define_token(360)
divider_color = _define_token("md.sys.color.outline")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.inner-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
headline_color = _define_token("md.sys.color.on-surface-variant")
headline_font = _define_token("md.sys.typescale.title-small.font")
headline_line_height = _define_token("md.sys.typescale.title-small.line-height")
headline_size = _define_token("md.sys.typescale.title-small.size")
headline_tracking = _define_token("md.sys.typescale.title-small.tracking")
headline_weight = _define_token("md.sys.typescale.title-small.weight")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
icon_size = _define_token(24)
inactive_focus_icon_color = _define_token("md.sys.color.on-surface")
inactive_focus_label_text_color = _define_token("md.sys.color.on-surface")
inactive_focus_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_hover_icon_color = _define_token("md.sys.color.on-surface")
inactive_hover_label_text_color = _define_token("md.sys.color.on-surface")
inactive_hover_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_icon_color = _define_token("md.sys.color.on-surface-variant")
inactive_label_text_color = _define_token("md.sys.color.on-surface-variant")
inactive_pressed_icon_color = _define_token("md.sys.color.on-surface")
inactive_pressed_label_text_color = _define_token("md.sys.color.on-surface")
inactive_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
label_text_font = _define_token("md.sys.typescale.label-large.font")
label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
label_text_size = _define_token("md.sys.typescale.label-large.size")
label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
label_text_weight = _define_token("md.sys.typescale.label-large.weight")
large_badge_label_color = _define_token("md.sys.color.on-surface-variant")
large_badge_label_font = _define_token("md.sys.typescale.label-large.font")
large_badge_label_line_height = _define_token("md.sys.typescale.label-large.line-height")
large_badge_label_size = _define_token("md.sys.typescale.label-large.size")
large_badge_label_tracking = _define_token("md.sys.typescale.label-large.tracking")
large_badge_label_weight = _define_token("md.sys.typescale.label-large.weight")
modal_container_color = _define_token("md.sys.color.surface-container-low")
modal_container_elevation = _define_token("md.sys.elevation.level1")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
scrim_color = _define_token("md.ref.palette.neutral-variant20")
scrim_opacity = _define_token(0.4)
standard_container_color = _define_token("md.sys.color.surface")
standard_container_elevation = _define_token("md.sys.elevation.level0")
