"""Design tokens for md.comp.time-picker."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

clock_dial_color = _define_token("md.sys.color.surface-container-highest")
clock_dial_color_ignore = _define_token("md.sys.color.on-surface-variant")
clock_dial_container_size = _define_token(256)
clock_dial_label_text_font = _define_token("md.sys.typescale.body-large.font")
clock_dial_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
clock_dial_label_text_size = _define_token("md.sys.typescale.body-large.size")
clock_dial_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
clock_dial_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
clock_dial_selected_label_text_color = _define_token("md.sys.color.on-primary")
clock_dial_selector_center_container_color = _define_token("md.sys.color.primary")
clock_dial_selector_center_container_shape = _define_token("md.sys.shape.corner.full")
clock_dial_selector_center_container_size = _define_token(8)
clock_dial_selector_handle_container_color = _define_token("md.sys.color.primary")
clock_dial_selector_handle_container_shape = _define_token("md.sys.shape.corner.full")
clock_dial_selector_handle_container_size = _define_token(48)
clock_dial_selector_track_container_color = _define_token("md.sys.color.primary")
clock_dial_selector_track_container_width = _define_token(2)
clock_dial_shape = _define_token("md.sys.shape.corner.full")
clock_dial_shape_ignore = _define_token("md.sys.shape.corner.full")
clock_dial_unselected_label_text_color = _define_token("md.sys.color.on-surface")
container_color = _define_token("md.sys.color.surface-container-high")
container_elevation = _define_token("md.sys.elevation.level3")
container_shape = _define_token("md.sys.shape.corner.extra-large")
headline_color = _define_token("md.sys.color.on-surface-variant")
headline_font = _define_token("md.sys.typescale.label-medium.font")
headline_line_height = _define_token("md.sys.typescale.label-medium.line-height")
headline_size = _define_token("md.sys.typescale.label-medium.size")
headline_tracking = _define_token("md.sys.typescale.label-medium.tracking")
headline_weight = _define_token("md.sys.typescale.label-medium.weight")
period_selector_container_shape = _define_token("md.sys.shape.corner.small")
period_selector_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
period_selector_horizontal_container_height = _define_token(38)
period_selector_horizontal_container_width = _define_token(216)
period_selector_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
period_selector_label_text_font = _define_token("md.sys.typescale.title-medium.font")
period_selector_label_text_line_height = _define_token("md.sys.typescale.title-medium.line-height")
period_selector_label_text_size = _define_token("md.sys.typescale.title-medium.size")
period_selector_label_text_tracking = _define_token("md.sys.typescale.title-medium.tracking")
period_selector_label_text_weight = _define_token("md.sys.typescale.title-medium.weight")
period_selector_outline_color = _define_token("md.sys.color.outline")
period_selector_outline_width = _define_token(1)
period_selector_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
period_selector_selected_container_color = _define_token("md.sys.color.tertiary-container")
period_selector_selected_focus_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_focus_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_hover_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_hover_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_pressed_label_text_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_selected_pressed_state_layer_color = _define_token("md.sys.color.on-tertiary-container")
period_selector_unselected_focus_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_pressed_label_text_color = _define_token("md.sys.color.on-surface-variant")
period_selector_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
period_selector_vertical_container_height = _define_token(80)
period_selector_vertical_container_width = _define_token(52)
surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
time_selector_24h_vertical_container_width = _define_token(114)
time_selector_container_height = _define_token(80)
time_selector_container_shape = _define_token("md.sys.shape.corner.small")
time_selector_container_width = _define_token(96)
time_selector_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
time_selector_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
time_selector_label_text_font = _define_token("md.sys.typescale.display-large.font")
time_selector_label_text_line_height = _define_token("md.sys.typescale.display-large.line-height")
time_selector_label_text_size = _define_token("md.sys.typescale.display-large.size")
time_selector_label_text_tracking = _define_token("md.sys.typescale.display-large.tracking")
time_selector_label_text_weight = _define_token("md.sys.typescale.display-large.weight")
time_selector_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
time_selector_selected_container_color = _define_token("md.sys.color.primary-container")
time_selector_selected_focus_label_text_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_focus_state_layer_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_hover_label_text_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_hover_state_layer_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_label_text_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_pressed_label_text_color = _define_token("md.sys.color.on-primary-container")
time_selector_selected_pressed_state_layer_color = _define_token("md.sys.color.on-primary-container")
time_selector_separator_color = _define_token("md.sys.color.on-surface")
time_selector_separator_font = _define_token("md.sys.typescale.display-large.font")
time_selector_separator_line_height = _define_token("md.sys.typescale.display-large.line-height")
time_selector_separator_size = _define_token("md.sys.typescale.display-large.size")
time_selector_separator_tracking = _define_token("md.sys.typescale.display-large.tracking")
time_selector_separator_weight = _define_token("md.sys.typescale.display-large.weight")
time_selector_unselected_container_color = _define_token("md.sys.color.surface-container-highest")
time_selector_unselected_focus_label_text_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_hover_label_text_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_label_text_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_pressed_label_text_color = _define_token("md.sys.color.on-surface")
time_selector_unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
