"""Design tokens for md.sys.state."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

dragged_state_layer_opacity = _define_token(0.16)
focus_indicator_inner_offset = _define_token(0)
focus_indicator_outer_offset = _define_token(2)
focus_indicator_thickness = _define_token(3)
focus_state_layer_opacity = _define_token(0.1)
hover_state_layer_opacity = _define_token(0.08)
pressed_state_layer_opacity = _define_token(0.1)
