"""Design tokens for md.comp.list."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

divider_color = _define_token("md.sys.color.outline")
divider_height = _define_token(1)
divider_leading_space = _define_token(16)
divider_trailing_space = _define_token(16)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.inner-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
list_item_container_color = _define_token("md.sys.color.surface")
list_item_container_elevation = _define_token("md.sys.elevation.level0")
list_item_container_height = _define_token(56)
list_item_container_shape = _define_token("md.sys.shape.corner.none")
list_item_disabled_label_text_color = _define_token("md.sys.color.on-surface")
list_item_disabled_label_text_opacity = _define_token(0.38)
list_item_disabled_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_disabled_leading_icon_opacity = _define_token(0.38)
list_item_disabled_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_disabled_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
list_item_disabled_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_disabled_trailing_icon_opacity = _define_token(0.38)
list_item_dragged_container_elevation = _define_token("md.sys.elevation.level4")
list_item_dragged_label_text_color = _define_token("md.sys.color.on-surface")
list_item_dragged_leading_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_dragged_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
list_item_dragged_trailing_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_focus_label_text_color = _define_token("md.sys.color.on-surface")
list_item_focus_leading_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_focus_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
list_item_focus_trailing_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_hover_label_text_color = _define_token("md.sys.color.on-surface")
list_item_hover_leading_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_hover_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
list_item_hover_trailing_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_label_text_color = _define_token("md.sys.color.on-surface")
list_item_label_text_font = _define_token("md.sys.typescale.body-large.font")
list_item_label_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
list_item_label_text_size = _define_token("md.sys.typescale.body-large.size")
list_item_label_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
list_item_label_text_weight = _define_token("md.sys.typescale.body-large.weight")
list_item_large_leading_video_height = _define_token(69)
list_item_leading_avatar_label_color = _define_token("md.sys.color.on-primary-container")
list_item_leading_avatar_label_font = _define_token("md.sys.typescale.title-medium.font")
list_item_leading_avatar_label_line_height = _define_token("md.sys.typescale.title-medium.line-height")
list_item_leading_avatar_label_size = _define_token("md.sys.typescale.title-medium.size")
list_item_leading_avatar_label_tracking = _define_token("md.sys.typescale.title-medium.tracking")
list_item_leading_avatar_label_weight = _define_token("md.sys.typescale.title-medium.weight")
list_item_leading_avatar_color = _define_token("md.sys.color.primary-container")
list_item_leading_avatar_shape = _define_token("md.sys.shape.corner.full")
list_item_leading_avatar_size = _define_token(40)
list_item_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_leading_icon_size = _define_token(24)
list_item_leading_image_height = _define_token(56)
list_item_leading_image_shape = _define_token("md.sys.shape.corner.none")
list_item_leading_image_width = _define_token(56)
list_item_leading_space = _define_token(16)
list_item_leading_video_shape = _define_token("md.sys.shape.corner.none")
list_item_leading_video_width = _define_token(100)
list_item_one_line_container_height = _define_token(56)
list_item_overline_color = _define_token("md.sys.color.on-surface-variant")
list_item_overline_font = _define_token("md.sys.typescale.label-small.font")
list_item_overline_line_height = _define_token("md.sys.typescale.label-small.line-height")
list_item_overline_size = _define_token("md.sys.typescale.label-small.size")
list_item_overline_tracking = _define_token("md.sys.typescale.label-small.tracking")
list_item_overline_weight = _define_token("md.sys.typescale.label-small.weight")
list_item_pressed_label_text_color = _define_token("md.sys.color.on-surface")
list_item_pressed_leading_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
list_item_pressed_trailing_icon_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_selected_container_color = _define_token("md.sys.color.secondary-container")
list_item_selected_dragged_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_dragged_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_dragged_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_selected_dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
list_item_selected_dragged_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_focus_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_focus_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_focus_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_selected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
list_item_selected_focus_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_hover_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_hover_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_hover_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_selected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
list_item_selected_hover_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_overline_color = _define_token("md.sys.color.on-surface")
list_item_selected_pressed_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_pressed_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_selected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
list_item_selected_pressed_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_selected_supporting_text_color = _define_token("md.sys.color.on-surface")
list_item_selected_trailing_icon_color = _define_token("md.sys.color.primary")
list_item_selected_trailing_supporting_text_color = _define_token("md.sys.color.on-surface")
list_item_small_leading_video_height = _define_token(56)
list_item_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
list_item_supporting_text_font = _define_token("md.sys.typescale.body-medium.font")
list_item_supporting_text_line_height = _define_token("md.sys.typescale.body-medium.line-height")
list_item_supporting_text_size = _define_token("md.sys.typescale.body-medium.size")
list_item_supporting_text_tracking = _define_token("md.sys.typescale.body-medium.tracking")
list_item_supporting_text_weight = _define_token("md.sys.typescale.body-medium.weight")
list_item_three_line_container_height = _define_token(88)
list_item_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_trailing_icon_size = _define_token(24)
list_item_trailing_space = _define_token(16)
list_item_trailing_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
list_item_trailing_supporting_text_font = _define_token("md.sys.typescale.label-small.font")
list_item_trailing_supporting_text_line_height = _define_token("md.sys.typescale.label-small.line-height")
list_item_trailing_supporting_text_size = _define_token("md.sys.typescale.label-small.size")
list_item_trailing_supporting_text_tracking = _define_token("md.sys.typescale.label-small.tracking")
list_item_trailing_supporting_text_weight = _define_token("md.sys.typescale.label-small.weight")
list_item_two_line_container_height = _define_token(72)
list_item_unselected_trailing_icon_color = _define_token("md.sys.color.on-surface")
md_comp_list_list_item_one_line_container_height = _define_token(56)
md_comp_list_list_item_three_line_container_height = _define_token(88)
md_comp_list_list_item_two_line_container_height = _define_token(72)
