"""Design tokens for md.comp.dialog."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

action_focus_label_text_color = _define_token("md.sys.color.primary")
action_focus_state_layer_color = _define_token("md.sys.color.primary")
action_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
action_hover_label_text_color = _define_token("md.sys.color.primary")
action_hover_state_layer_color = _define_token("md.sys.color.primary")
action_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
action_label_text_color = _define_token("md.sys.color.primary")
action_label_text_font = _define_token("md.sys.typescale.label-large.font")
action_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
action_label_text_size = _define_token("md.sys.typescale.label-large.size")
action_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
action_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
action_pressed_label_text_color = _define_token("md.sys.color.primary")
action_pressed_state_layer_color = _define_token("md.sys.color.primary")
action_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
container_color = _define_token("md.sys.color.surface-container-high")
container_elevation = _define_token("md.sys.elevation.level3")
container_shape = _define_token("md.sys.shape.corner.extra-large")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
headline_color = _define_token("md.sys.color.on-surface")
headline_font = _define_token("md.sys.typescale.headline-small.font")
headline_line_height = _define_token("md.sys.typescale.headline-small.line-height")
headline_size = _define_token("md.sys.typescale.headline-small.size")
headline_tracking = _define_token("md.sys.typescale.headline-small.tracking")
headline_weight = _define_token("md.sys.typescale.headline-small.weight")
subhead_color = _define_token("md.sys.color.on-surface")
subhead_font = _define_token("md.sys.typescale.headline-small.font")
subhead_line_height = _define_token("md.sys.typescale.headline-small.line-height")
subhead_size = _define_token("md.sys.typescale.headline-small.size")
subhead_tracking = _define_token("md.sys.typescale.headline-small.tracking")
subhead_weight = _define_token("md.sys.typescale.headline-small.weight")
supporting_text_color = _define_token("md.sys.color.on-surface-variant")
supporting_text_font = _define_token("md.sys.typescale.body-medium.font")
supporting_text_line_height = _define_token("md.sys.typescale.body-medium.line-height")
supporting_text_size = _define_token("md.sys.typescale.body-medium.size")
supporting_text_tracking = _define_token("md.sys.typescale.body-medium.tracking")
supporting_text_weight = _define_token("md.sys.typescale.body-medium.weight")
with_divider_divider_color = _define_token("md.sys.color.outline")
with_divider_divider_height = _define_token(1)
with_icon_icon_color = _define_token("md.sys.color.secondary")
with_icon_icon_size = _define_token(24)
