"""Design tokens for md.sys.elevation."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

level0 = _define_token(0)
level1 = _define_token(1)
level2 = _define_token(3)
level3 = _define_token(6)
level4 = _define_token(8)
