"""Design tokens for md.comp.menu."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

cascading_menu_indicator_icon_color = _define_token("md.sys.color.on-surface-variant")
cascading_menu_indicator_icon_size = _define_token(24)
container_color = _define_token("md.sys.color.surface-container")
container_elevation = _define_token("md.sys.elevation.level2")
container_shadow_color = _define_token("md.sys.color.shadow")
container_shape = _define_token("md.sys.shape.corner.extra-small")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
divider_color = _define_token("md.sys.color.surface-variant")
divider_height = _define_token(1)
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.inner-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
list_item_container_height = _define_token(48)
list_item_disabled_label_text_color = _define_token("md.sys.color.on-surface")
list_item_disabled_label_text_opacity = _define_token(0.38)
list_item_focus_label_text_color = _define_token("md.sys.color.on-surface")
list_item_focus_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
list_item_hover_label_text_color = _define_token("md.sys.color.on-surface")
list_item_hover_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
list_item_label_text_color = _define_token("md.sys.color.on-surface")
list_item_label_text_font = _define_token("md.sys.typescale.label-large.font")
list_item_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
list_item_label_text_size = _define_token("md.sys.typescale.label-large.size")
list_item_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
list_item_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
list_item_pressed_label_text_color = _define_token("md.sys.color.on-surface")
list_item_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
list_item_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
list_item_selected_container_color = _define_token("md.sys.color.secondary-container")
list_item_selected_label_text_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_with_leading_icon_leading_icon_color = _define_token("md.sys.color.on-secondary-container")
list_item_selected_with_leading_icon_trailing_icon_color = _define_token("md.sys.color.on-secondary-container")
list_item_with_leading_icon_disabled_leading_icon_color = _define_token("md.sys.color.on-surface")
list_item_with_leading_icon_disabled_leading_icon_opacity = _define_token(0.38)
list_item_with_leading_icon_focus_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_leading_icon_hover_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_leading_icon_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_leading_icon_leading_icon_size = _define_token(24)
list_item_with_leading_icon_pressed_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_trailing_icon_disabled_trailing_icon_color = _define_token("md.sys.color.on-surface")
list_item_with_trailing_icon_disabled_trailing_icon_opacity = _define_token(0.38)
list_item_with_trailing_icon_focus_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_trailing_icon_hover_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_trailing_icon_pressed_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_trailing_icon_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
list_item_with_trailing_icon_trailing_icon_size = _define_token(24)
