"""Design tokens for md.comp.navigation-rail."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

active_indicator_color = _define_token("md.sys.color.secondary-container")
active_indicator_height = _define_token(32)
active_indicator_shape = _define_token("md.sys.shape.corner.full")
active_indicator_width = _define_token(56)
active_focus_icon_color = _define_token("md.sys.color.on-secondary-container")
active_focus_label_text_color = _define_token("md.sys.color.on-surface")
active_focus_state_layer_color = _define_token("md.sys.color.on-surface")
active_hover_icon_color = _define_token("md.sys.color.on-secondary-container")
active_hover_label_text_color = _define_token("md.sys.color.on-surface")
active_hover_state_layer_color = _define_token("md.sys.color.on-surface")
active_icon_color = _define_token("md.sys.color.on-secondary-container")
active_label_text_color = _define_token("md.sys.color.on-surface")
active_label_text_weight = _define_token("md.sys.typescale.label-medium.weight.prominent")
active_pressed_icon_color = _define_token("md.sys.color.on-secondary-container")
active_pressed_label_text_color = _define_token("md.sys.color.on-surface")
active_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
badge_color = _define_token("md.sys.color.error")
badge_shape = _define_token("SHAPE_FAMILY_ROUNDED_CORNERS")
badge_size = _define_token(6)
container_color = _define_token("md.sys.color.surface")
container_elevation = _define_token("md.sys.elevation.level0")
container_shape = _define_token("md.sys.shape.corner.none")
container_width = _define_token(80)
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
icon_size = _define_token(24)
inactive_focus_icon_color = _define_token("md.sys.color.on-surface")
inactive_focus_label_text_color = _define_token("md.sys.color.on-surface")
inactive_focus_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_hover_icon_color = _define_token("md.sys.color.on-surface")
inactive_hover_label_text_color = _define_token("md.sys.color.on-surface")
inactive_hover_state_layer_color = _define_token("md.sys.color.on-surface")
inactive_icon_color = _define_token("md.sys.color.on-surface-variant")
inactive_label_text_color = _define_token("md.sys.color.on-surface-variant")
inactive_pressed_icon_color = _define_token("md.sys.color.on-surface")
inactive_pressed_label_text_color = _define_token("md.sys.color.on-surface")
inactive_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
label_text_font = _define_token("md.sys.typescale.label-medium.font")
label_text_font_family = _define_token("md.sys.typescale.label-medium.font")
label_text_font_size = _define_token("md.sys.typescale.label-medium.size")
label_text_letter_spacing = _define_token("md.sys.typescale.label-medium.tracking")
label_text_line_height = _define_token("md.sys.typescale.label-medium.line-height")
label_text_size = _define_token("md.sys.typescale.label-medium.size")
label_text_tracking = _define_token("md.sys.typescale.label-medium.tracking")
label_text_weight = _define_token("md.sys.typescale.label-medium.weight")
large_badge_label_color = _define_token("md.sys.color.on-error")
large_badge_label_font = _define_token("md.sys.typescale.label-small.font")
large_badge_label_font_family = _define_token("md.sys.typescale.label-small.font")
large_badge_label_line_height = _define_token("md.sys.typescale.label-small.line-height")
large_badge_label_size = _define_token("md.sys.typescale.label-small.size")
large_badge_label_tracking = _define_token("md.sys.typescale.label-small.tracking")
large_badge_label_weight = _define_token("md.sys.typescale.label-small.weight")
large_badge_color = _define_token("md.sys.color.error")
large_badge_shape = _define_token("SHAPE_FAMILY_ROUNDED_CORNERS")
large_badge_size = _define_token(16)
menu_focus_icon_color = _define_token("md.sys.color.on-surface")
menu_focus_state_layer_color = _define_token("md.sys.color.on-surface")
menu_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
menu_hover_icon_color = _define_token("md.sys.color.on-surface")
menu_hover_state_layer_color = _define_token("md.sys.color.on-surface")
menu_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
menu_icon_color = _define_token("md.sys.color.on-surface-variant")
menu_icon_size = _define_token(24)
menu_pressed_icon_color = _define_token("md.sys.color.on-surface")
menu_pressed_state_layer_color = _define_token("md.sys.color.on-surface")
menu_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
no_label_active_indicator_height = _define_token(56)
no_label_active_indicator_shape = _define_token("md.sys.shape.corner.full")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
