"""Design tokens for md.comp.search-bar."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

avatar_shape = _define_token("md.sys.shape.corner.full")
avatar_size = _define_token(30)
container_color = _define_token("md.sys.color.surface-container-high")
container_elevation = _define_token("md.sys.elevation.level3")
container_height = _define_token(56)
container_shape = _define_token("md.sys.shape.corner.full")
container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
hover_state_layer_color = _define_token("md.sys.color.on-surface")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
hover_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
input_text_color = _define_token("md.sys.color.on-surface")
input_text_font = _define_token("md.sys.typescale.body-large.font")
input_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
input_text_size = _define_token("md.sys.typescale.body-large.size")
input_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
input_text_weight = _define_token("md.sys.typescale.body-large.weight")
leading_icon_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_color = _define_token("md.sys.color.on-surface")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
pressed_supporting_text_color = _define_token("md.sys.color.on-surface-variant")
supporting_text_color = _define_token("md.sys.color.on-surface-variant")
supporting_text_font = _define_token("md.sys.typescale.body-large.font")
supporting_text_line_height = _define_token("md.sys.typescale.body-large.line-height")
supporting_text_size = _define_token("md.sys.typescale.body-large.size")
supporting_text_tracking = _define_token("md.sys.typescale.body-large.tracking")
supporting_text_weight = _define_token("md.sys.typescale.body-large.weight")
trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
