"""Design tokens for md.comp.top-app-bar."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

large_container_color = _define_token("md.sys.color.surface")
large_container_elevation = _define_token("md.sys.elevation.level0")
large_container_height = _define_token(152)
large_container_shape = _define_token("md.sys.shape.corner.none")
large_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
large_headline_color = _define_token("md.sys.color.on-surface")
large_headline_font = _define_token("md.sys.typescale.headline-medium.font")
large_headline_line_height = _define_token("md.sys.typescale.headline-medium.line-height")
large_headline_size = _define_token("md.sys.typescale.headline-medium.size")
large_headline_tracking = _define_token("md.sys.typescale.headline-medium.tracking")
large_headline_weight = _define_token("md.sys.typescale.headline-medium.weight")
large_leading_icon_color = _define_token("md.sys.color.on-surface")
large_leading_icon_size = _define_token(24)
large_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
large_trailing_icon_size = _define_token(24)
medium_container_color = _define_token("md.sys.color.surface")
medium_container_elevation = _define_token("md.sys.elevation.level0")
medium_container_height = _define_token(112)
medium_container_shape = _define_token("md.sys.shape.corner.none")
medium_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
medium_headline_color = _define_token("md.sys.color.on-surface")
medium_headline_font = _define_token("md.sys.typescale.headline-small.font")
medium_headline_line_height = _define_token("md.sys.typescale.headline-small.line-height")
medium_headline_size = _define_token("md.sys.typescale.headline-small.size")
medium_headline_tracking = _define_token("md.sys.typescale.headline-small.tracking")
medium_headline_weight = _define_token("md.sys.typescale.headline-small.weight")
medium_leading_icon_color = _define_token("md.sys.color.on-surface")
medium_leading_icon_size = _define_token(24)
medium_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
medium_trailing_icon_size = _define_token(24)
small_centered_avatar_shape = _define_token("md.sys.shape.corner.full")
small_centered_avatar_size = _define_token(30)
small_centered_container_color = _define_token("md.sys.color.surface")
small_centered_container_elevation = _define_token("md.sys.elevation.level0")
small_centered_container_height = _define_token(64)
small_centered_container_shape = _define_token("md.sys.shape.corner.none")
small_centered_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
small_centered_headline_color = _define_token("md.sys.color.on-surface")
small_centered_headline_font = _define_token("md.sys.typescale.title-large.font")
small_centered_headline_line_height = _define_token("md.sys.typescale.title-large.line-height")
small_centered_headline_size = _define_token("md.sys.typescale.title-large.size")
small_centered_headline_tracking = _define_token("md.sys.typescale.title-large.tracking")
small_centered_headline_weight = _define_token("md.sys.typescale.title-large.weight")
small_centered_leading_icon_color = _define_token("md.sys.color.on-surface")
small_centered_leading_icon_size = _define_token(24)
small_centered_on_scroll_container_color = _define_token("md.sys.color.surface-container")
small_centered_on_scroll_container_elevation = _define_token("md.sys.elevation.level2")
small_centered_on_scroll_container_shadow_color = _define_token("md.sys.color.shadow")
small_centered_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
small_centered_trailing_icon_size = _define_token(24)
small_container_color = _define_token("md.sys.color.surface")
small_container_elevation = _define_token("md.sys.elevation.level0")
small_container_height = _define_token(64)
small_container_shape = _define_token("md.sys.shape.corner.none")
small_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
small_headline_color = _define_token("md.sys.color.on-surface")
small_headline_font = _define_token("md.sys.typescale.title-large.font")
small_headline_line_height = _define_token("md.sys.typescale.title-large.line-height")
small_headline_size = _define_token("md.sys.typescale.title-large.size")
small_headline_tracking = _define_token("md.sys.typescale.title-large.tracking")
small_headline_weight = _define_token("md.sys.typescale.title-large.weight")
small_leading_icon_color = _define_token("md.sys.color.on-surface")
small_leading_icon_size = _define_token(24)
small_on_scroll_container_color = _define_token("md.sys.color.surface-container")
small_on_scroll_container_elevation = _define_token("md.sys.elevation.level2")
small_on_scroll_container_shadow_color = _define_token("md.sys.color.shadow")
small_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
small_trailing_icon_size = _define_token(24)
