"""Design tokens for md.comp.full-screen-dialog."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

action_bar_container_color = _define_token("md.sys.color.surface")
action_bar_container_elevation = _define_token("md.sys.elevation.level0")
action_bar_container_height = _define_token(56)
action_bar_focus_label_text_color = _define_token("md.sys.color.primary")
action_bar_focus_state_layer_color = _define_token("md.sys.color.primary")
action_bar_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
action_bar_hover_label_text_color = _define_token("md.sys.color.primary")
action_bar_hover_state_layer_color = _define_token("md.sys.color.primary")
action_bar_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
action_bar_label_text_color = _define_token("md.sys.color.primary")
action_bar_label_text_font = _define_token("md.sys.typescale.label-large.font")
action_bar_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
action_bar_label_text_size = _define_token("md.sys.typescale.label-large.size")
action_bar_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
action_bar_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
action_bar_on_scroll_container_elevation = _define_token("md.sys.elevation.level2")
action_bar_pressed_label_text_color = _define_token("md.sys.color.primary")
action_bar_pressed_state_layer_color = _define_token("md.sys.color.primary")
action_bar_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
container_color = _define_token("md.sys.color.surface")
container_elevation = _define_token("md.sys.elevation.level0")
container_shape = _define_token("md.sys.shape.corner.none")
header_action_focus_label_text_color = _define_token("md.sys.color.primary")
header_action_focus_state_layer_color = _define_token("md.sys.color.primary")
header_action_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
header_action_hover_label_text_color = _define_token("md.sys.color.primary")
header_action_hover_state_layer_color = _define_token("md.sys.color.primary")
header_action_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
header_action_label_text_color = _define_token("md.sys.color.primary")
header_action_label_text_font = _define_token("md.sys.typescale.label-large.font")
header_action_label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
header_action_label_text_size = _define_token("md.sys.typescale.label-large.size")
header_action_label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
header_action_label_text_weight = _define_token("md.sys.typescale.label-large.weight")
header_action_pressed_label_text_color = _define_token("md.sys.color.primary")
header_action_pressed_state_layer_color = _define_token("md.sys.color.primary")
header_action_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
header_container_color = _define_token("md.sys.color.surface")
header_container_elevation = _define_token("md.sys.elevation.level0")
header_container_height = _define_token(56)
header_container_surface_tint_layer_color = _define_token("md.sys.color.surface-tint")
header_headline_color = _define_token("md.sys.color.on-surface")
header_headline_font = _define_token("md.sys.typescale.title-large.font")
header_headline_line_height = _define_token("md.sys.typescale.title-large.line-height")
header_headline_size = _define_token("md.sys.typescale.title-large.size")
header_headline_tracking = _define_token("md.sys.typescale.title-large.tracking")
header_headline_weight = _define_token("md.sys.typescale.title-large.weight")
header_icon_color = _define_token("md.sys.color.on-surface")
header_icon_size = _define_token(24)
header_on_scroll_container_color = _define_token("md.sys.color.surface-container")
header_on_scroll_container_elevation = _define_token("md.sys.elevation.level2")
with_divider_divider_color = _define_token("md.sys.color.surface-variant")
with_divider_divider_height = _define_token(1)
