"""Design tokens for md.comp.input-chip."""

# Auto generated by _token_converter.py
# Do not edit this file directly.

from material_ui.tokens._utils import define_token as _define_token

container_elevation = _define_token("md.sys.elevation.level0")
container_height = _define_token(32)
container_shape = _define_token("md.sys.shape.corner.small")
disabled_label_text_color = _define_token("md.sys.color.on-surface")
disabled_label_text_opacity = _define_token(0.38)
disabled_outline_color = _define_token("md.sys.color.on-surface")
disabled_outline_opacity = _define_token(0.12)
disabled_selected_container_color = _define_token("md.sys.color.on-surface")
disabled_selected_container_opacity = _define_token(0.12)
disabled_unselected_outline_color = _define_token("md.sys.color.on-surface")
disabled_unselected_outline_opacity = _define_token(0.12)
dragged_container_elevation = _define_token("md.sys.elevation.level4")
dragged_label_text_color = _define_token("md.sys.color.on-surface-variant")
dragged_state_layer_color = _define_token("md.sys.color.on-surface-variant")
dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
focus_indicator_color = _define_token("md.sys.color.secondary")
focus_indicator_outline_offset = _define_token("md.sys.state.focus-indicator.outer-offset")
focus_indicator_thickness = _define_token("md.sys.state.focus-indicator.thickness")
focus_label_text_color = _define_token("md.sys.color.on-surface-variant")
focus_outline_color = _define_token("md.sys.color.on-surface-variant")
focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
label_text_color = _define_token("md.sys.color.on-surface-variant")
label_text_font = _define_token("md.sys.typescale.label-large.font")
label_text_line_height = _define_token("md.sys.typescale.label-large.line-height")
label_text_size = _define_token("md.sys.typescale.label-large.size")
label_text_tracking = _define_token("md.sys.typescale.label-large.tracking")
label_text_weight = _define_token("md.sys.typescale.label-large.weight")
outline_color = _define_token("md.sys.color.outline")
outline_width = _define_token(1)
pressed_label_text_color = _define_token("md.sys.color.on-surface-variant")
pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
selected_container_color = _define_token("md.sys.color.secondary-container")
selected_dragged_label_text_color = _define_token("md.sys.color.on-secondary-container")
selected_dragged_state_layer_color = _define_token("md.sys.color.on-secondary-container")
selected_dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
selected_focus_label_text_color = _define_token("md.sys.color.on-secondary-container")
selected_focus_state_layer_color = _define_token("md.sys.color.on-secondary-container")
selected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
selected_hover_label_text_color = _define_token("md.sys.color.on-secondary-container")
selected_hover_state_layer_color = _define_token("md.sys.color.on-secondary-container")
selected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
selected_label_text_color = _define_token("md.sys.color.on-secondary-container")
selected_outline_width = _define_token(0)
selected_pressed_label_text_color = _define_token("md.sys.color.on-secondary-container")
selected_pressed_state_layer_color = _define_token("md.sys.color.on-secondary-container")
selected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
unselected_dragged_label_text_color = _define_token("md.sys.color.on-surface-variant")
unselected_dragged_state_layer_color = _define_token("md.sys.color.on-surface-variant")
unselected_dragged_state_layer_opacity = _define_token("md.sys.state.dragged.state-layer-opacity")
unselected_focus_label_text_color = _define_token("md.sys.color.on-surface-variant")
unselected_focus_outline_color = _define_token("md.sys.color.on-surface-variant")
unselected_focus_state_layer_color = _define_token("md.sys.color.on-surface-variant")
unselected_focus_state_layer_opacity = _define_token("md.sys.state.focus.state-layer-opacity")
unselected_hover_label_text_color = _define_token("md.sys.color.on-surface-variant")
unselected_hover_state_layer_color = _define_token("md.sys.color.on-surface-variant")
unselected_hover_state_layer_opacity = _define_token("md.sys.state.hover.state-layer-opacity")
unselected_label_text_color = _define_token("md.sys.color.on-surface-variant")
unselected_outline_color = _define_token("md.sys.color.outline-variant")
unselected_outline_width = _define_token(1)
unselected_pressed_label_text_color = _define_token("md.sys.color.on-surface-variant")
unselected_pressed_state_layer_color = _define_token("md.sys.color.on-surface-variant")
unselected_pressed_state_layer_opacity = _define_token("md.sys.state.pressed.state-layer-opacity")
with_avatar_avatar_shape = _define_token("md.sys.shape.corner.full")
with_avatar_avatar_size = _define_token(24)
with_avatar_disabled_avatar_opacity = _define_token(0.38)
with_leading_icon_disabled_leading_icon_color = _define_token("md.sys.color.on-surface")
with_leading_icon_disabled_leading_icon_opacity = _define_token(0.38)
with_leading_icon_dragged_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_focus_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_hover_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_leading_icon_size = _define_token(18)
with_leading_icon_pressed_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_selected_dragged_leading_icon_color = _define_token("md.sys.color.on-secondary-container")
with_leading_icon_selected_focus_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_selected_hover_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_selected_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_selected_pressed_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_unselected_dragged_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_unselected_focus_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_unselected_hover_leading_icon_color = _define_token("md.sys.color.primary")
with_leading_icon_unselected_leading_icon_color = _define_token("md.sys.color.on-surface-variant")
with_leading_icon_unselected_pressed_leading_icon_color = _define_token("md.sys.color.primary")
with_trailing_icon_disabled_trailing_icon_color = _define_token("md.sys.color.on-surface")
with_trailing_icon_disabled_trailing_icon_opacity = _define_token(0.38)
with_trailing_icon_dragged_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_focus_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_hover_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_pressed_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_selected_dragged_trailing_icon_color = _define_token("md.sys.color.primary")
with_trailing_icon_selected_focus_trailing_icon_color = _define_token("md.sys.color.on-secondary-container")
with_trailing_icon_selected_hover_trailing_icon_color = _define_token("md.sys.color.on-secondary-container")
with_trailing_icon_selected_pressed_trailing_icon_color = _define_token("md.sys.color.on-secondary-container")
with_trailing_icon_selected_trailing_icon_color = _define_token("md.sys.color.on-secondary-container")
with_trailing_icon_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_trailing_icon_size = _define_token(18)
with_trailing_icon_unselected_dragged_trailing_icon_color = _define_token("md.sys.color.primary")
with_trailing_icon_unselected_focus_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_unselected_hover_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_unselected_pressed_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
with_trailing_icon_unselected_trailing_icon_color = _define_token("md.sys.color.on-surface-variant")
